static const char *const kEoB1ChargenStrings1PC98Japanese[9] = {
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcd\x8f""o""\x97\x88\x8f\xe3\x82\xaa\x82\xe8\x82\xdc\x82\xb5\x82\xbd\x81""B\r""\x81""u""\x82""o""\x82""k""\x82""`""\x82""x""\x81""v""\x82\xf0\x91""I""\x82\xd4\x82\xa9\x81""u""\x82""o""\x81""v""\x82\xf0\x89\x9f\x82\xb7\x82\xc6""\r""\x83""Q""\x81""[""\x83\x80\x82\xaa\x8e""n""\x82\xdc\x82\xe8\x82\xdc\x82\xb7\x81""B",
	"          ",
	"AC\rHP\rLVL",
	"%s\r%d\r%d\r%d\r%d\r%d",
	"%d\r%d",
	"%d",
	"%d/%d",
	"%d/%d/%d",
	"\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xf0\x8d\xec\x82\xe8\x82\xbd\x82\xa2\x83""{""\x83""b""\x83""N""\x83""X""\x82\xa9\x81""A\r""\x8f\xda\x8d\xd7\x82\xf0\x8c\xa9\x82\xbd\x82\xa2\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xcc\x83""{""\x83""b""\x83""N""\x83""X""\x82\xf0""\r""\x91""I""\x82\xf1\x82\xc5\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""B"
};

static const StringListProvider kEoB1ChargenStrings1PC98JapaneseProvider = { ARRAYSIZE(kEoB1ChargenStrings1PC98Japanese), kEoB1ChargenStrings1PC98Japanese };

static const char *const kEoB1ChargenStrings2PC98Japanese[12] = {
	"%s",
	"%d",
	"%s",
	"%d",
	"%d",
	"%d",
	"%s",
	"%d",
	"\x8e\xed\x91\xb0\x82\xf0\x91""I""\x82\xf1\x82\xc5\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""F",
	"\x83""N""\x83\x89\x83""X""\x82\xf0\x91""I""\x82\xf1\x82\xc5\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""F",
	"\x83""A""\x83\x89\x83""C""\x83\x93\x83\x81\x83\x93\x83""g""\x82\xf0\x91""I""\x82\xf1\x82\xc5\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""F",
	"\x96\xbc\x91""O""\x81""F"
};

static const StringListProvider kEoB1ChargenStrings2PC98JapaneseProvider = { ARRAYSIZE(kEoB1ChargenStrings2PC98Japanese), kEoB1ChargenStrings2PC98Japanese };

static const char *const kEoB1ChargenStatStringsPC98Japanese[12] = {
	"\x91\xcc\x97\xcd\x93""x",
	"\x92""m""\x90\xab\x93""x",
	"\x8c\xab\x96\xbe\x93""x",
	"\x95""q""\x8f\xb7\x93""x",
	"\x91\xcf\x8b""v""\x93""x",
	"\x96\xa3\x97\xcd\x93""x",
	"\x91\xcc\x97\xcd\x93""x",
	"\x92""m""\x90\xab\x93""x",
	"\x8c\xab\x96\xbe\x93""x",
	"\x95""q""\x8f\xb7\x93""x",
	"\x91\xcf\x8b""v""\x93""x",
	"\x96\xa3\x97\xcd\x93""x"
};

static const StringListProvider kEoB1ChargenStatStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1ChargenStatStringsPC98Japanese), kEoB1ChargenStatStringsPC98Japanese };

static const char *const kEoB1ChargenRaceSexStringsPC98Japanese[12] = {
	"\x90""l""\x8a\xd4\x81""@""\x92""j",
	"\x90""l""\x8a\xd4\x81""@""\x8f\x97",
	"\x83""G""\x83\x8b\x83""t""\x81""@""\x92""j",
	"\x83""G""\x83\x8b\x83""t""\x81""@""\x8f\x97",
	"\x83""n""\x81""[""\x83""t""\x81""E""\x83""G""\x83\x8b\x83""t""\x81""@""\x92""j",
	"\x83""n""\x81""[""\x83""t""\x81""E""\x83""G""\x83\x8b\x83""t""\x81""@""\x8f\x97",
	"\x83""h""\x83\x8f\x81""[""\x83""t""\x81""@""\x92""j",
	"\x83""h""\x83\x8f\x81""[""\x83""t""\x81""@""\x8f\x97",
	"\x83""m""\x81""[""\x83\x80\x81""@""\x92""j",
	"\x83""m""\x81""[""\x83\x80\x81""@""\x8f\x97",
	"\x83""n""\x81""[""\x83""t""\x83\x8a\x83\x93\x83""O""\x81""@""\x92""j",
	"\x83""n""\x81""[""\x83""t""\x83\x8a\x83\x93\x83""O""\x81""@""\x8f\x97"
};

static const StringListProvider kEoB1ChargenRaceSexStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1ChargenRaceSexStringsPC98Japanese), kEoB1ChargenRaceSexStringsPC98Japanese };

static const char *const kEoB1ChargenClassStringsPC98Japanese[21] = {
	"\x90\xed\x8e""m",
	"\x83\x8c\x83\x93\x83""W""\x83\x83\x81""[",
	"\x90\xb9\x8b""R""\x8e""m",
	"\x96\x82\x96""@""\x8e""g""\x82\xa2",
	"\x91""m""\x97\xb5",
	"\x93\x90\x91\xaf",
	"\x90\xed\x8e""m""\x81""^""\x91""m""\x97\xb5",
	"\x90\xed\x8e""m""\x81""^""\x93\x90\x91\xaf",
	"\x90\xed\x8e""m""\x81""^""\x96\x82\x96""@""\x8e""g""\x82\xa2",
	"\x90\xed\x8e""m""\x81""^""\x96\x82\x96""@""\x8e""g""\x82\xa2\x81""^""\x93\x90\x91\xaf",
	"\x93\x90\x91\xaf\x81""^""\x96\x82\x96""@""\x8e""g""\x82\xa2",
	"\x91""m""\x97\xb5\x81""^""\x93\x90\x91\xaf",
	"\x90\xed\x8e""m""\x81""^""\x91""m""\x97\xb5\x81""^""\x96\x82\x96""@""\x8e""g""\x82\xa2",
	"\x83\x8c\x83\x93\x83""W""\x83\x83\x81""[""\x81""^""\x91""m""\x97\xb5",
	"\x91""m""\x97\xb5\x81""^""\x96\x82\x96""@""\x8e""g""\x82\xa2",
	"\x90\xed\x8e""m",
	"\x96\x82\x96""@""\x8e""g""\x82\xa2",
	"\x91""m""\x97\xb5",
	"\x93\x90\x91\xaf",
	"\x90\xb9\x8b""R""\x8e""m",
	"\x83\x8c\x83\x93\x83""W""\x83\x83\x81""["
};

static const StringListProvider kEoB1ChargenClassStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1ChargenClassStringsPC98Japanese), kEoB1ChargenClassStringsPC98Japanese };

static const char *const kEoB1ChargenAlignmentStringsPC98Japanese[9] = {
	"\x83\x8d\x81""[""\x83""t""\x83\x8b\x81""E""\x83""O""\x83""b""\x83""h",
	"\x83""j""\x83\x85\x81""[""\x83""g""\x83\x89\x83\x8b\x81""E""\x83""O""\x83""b""\x83""h",
	"\x83""P""\x83""C""\x83""I""\x83""e""\x83""B""\x83""b""\x83""N""\x81""E""\x83""O""\x83""b""\x83""h",
	"\x83\x8d\x81""[""\x83""t""\x83\x8b\x81""E""\x83""j""\x83\x85\x81""[""\x83""g""\x83\x89\x83\x8b",
	"\x83""g""\x83""D""\x83\x8b\x81""[""\x81""E""\x83""j""\x83\x85\x81""[""\x83""g""\x83\x89\x83\x8b",
	"\x83""P""\x83""C""\x83""I""\x83""e""\x83""B""\x83""b""\x83""N""\x81""E""\x83""j""\x83\x85\x81""[""\x83""g""\x83\x89\x83\x8b",
	"\x83\x8d\x81""[""\x83""t""\x83\x8b\x81""E""\x83""C""\x81""[""\x83""r""\x83\x8b",
	"\x83""j""\x83\x85\x81""[""\x83""g""\x83\x89\x83\x8b\x81""E""\x83""C""\x81""[""\x83""r""\x83\x8b",
	"\x83""P""\x83""C""\x83""I""\x83""e""\x83""B""\x83""b""\x83""N""\x81""E""\x83""C""\x81""[""\x83""r""\x83\x8b"
};

static const StringListProvider kEoB1ChargenAlignmentStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1ChargenAlignmentStringsPC98Japanese), kEoB1ChargenAlignmentStringsPC98Japanese };

static const char *const kEoB1ChargenEnterGameStringsPC98Japanese[1] = {
	"\x81""@""\x81""@""\x83""Q""\x81""[""\x83\x80\x82\xf0\x8e""n""\x82\xdf\x82\xdc\x82\xb7\x81""B\r""\x81""@""\x81""@""\x82\xb5\x82\xce\x82\xe7\x82\xad\x82\xa8\x91\xd2\x82\xbf\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""B"
};

static const StringListProvider kEoB1ChargenEnterGameStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1ChargenEnterGameStringsPC98Japanese), kEoB1ChargenEnterGameStringsPC98Japanese };

static const char *const kEoB1MainMenuStringsPC98Japanese[3] = {
	"\x90""i""\x8d""s""\x92\x86\x82\xcc\x83""Q""\x81""[""\x83\x80\x8f\xee\x95\xf1\x82\xf0\x93\xc7\x82\xdd\x82\xb1\x82\xde""\r",
	"\x90""V""\x82\xb5\x82\xa2\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xc5\x8e""n""\x82\xdf\x82\xe9""\r",
	"\x83""Q""\x81""[""\x83\x80\x83\x86\x81""[""\x83""e""\x83""B""\x83\x8a\x83""e""\x83""B\r"
};

static const StringListProvider kEoB1MainMenuStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1MainMenuStringsPC98Japanese), kEoB1MainMenuStringsPC98Japanese };


static const char *const kEoB1BonusStringsPC98Japanese[3] = {
	"\x83""p""\x81""[""\x83""e""\x83""B""\x82\xcc\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xcc\x96\xbc\x91""O""\x82\xcd\x8e\x9f\x82\xcc\x92\xca\x82\xe8\x82\xc5\x82\xb7\x81""B",
	"\r",
	"\x83""p""\x83""X""\x83\x8f\x81""[""\x83""h""\x81""F%04x"
};

static const StringListProvider kEoB1BonusStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1BonusStringsPC98Japanese), kEoB1BonusStringsPC98Japanese };

static const char *const kEoB1TurnUndeadStringPC98Japanese[1] = {
	"\x06\x06""%s""\x82\xcd\x83""A""\x83\x93\x83""f""\x83""b""\x83""g""\x82\xf0\x91\xde\x8e""U""\x82\xb3\x82\xb9\x82\xe6\x82\xa4\x82\xc6\x8e\x8e\x82\xdd\x82\xbd\x81""I""\x06\x0f""\r"
};

static const StringListProvider kEoB1TurnUndeadStringPC98JapaneseProvider = { ARRAYSIZE(kEoB1TurnUndeadStringPC98Japanese), kEoB1TurnUndeadStringPC98Japanese };

static const char *const kEoB1Npc0StringsPC98Japanese[2] = {
	"\r     ""\x82\xb2\x8d""K""\x89""^""\x82\xf0\x8b""F""\x82\xe8\x82\xdc\x82\xb7\x81""B",
	"\x92""N""\x82\xf0\x95\x9c\x8a\x88\x82\xb3\x82\xb9\x82\xdc\x82\xb7\x82\xa9\x81""H"
};

static const StringListProvider kEoB1Npc0StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc0StringsPC98Japanese), kEoB1Npc0StringsPC98Japanese };

static const char *const kEoB1Npc11StringsPC98Japanese[3] = {
	"\x8f\x9d\x82\xcc\x8e\xe8\x93\x96\x82\xf0\x82\xb7\x82\xe9",
	"\x98""b""\x82\xb5\x82\xa9\x82\xaf\x82\xe9",
	"\x97\xa7\x82\xbf\x8b\x8e\x82\xe9"
};

static const StringListProvider kEoB1Npc11StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc11StringsPC98Japanese), kEoB1Npc11StringsPC98Japanese };

static const char *const kEoB1Npc12StringsPC98Japanese[2] = {
	"\x8f\x9d\x82\xcc\x8e\xe8\x93\x96\x82\xf0\x82\xb7\x82\xe9",
	"\x97\xa7\x82\xbf\x8b\x8e\x82\xe9"
};

static const StringListProvider kEoB1Npc12StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc12StringsPC98Japanese), kEoB1Npc12StringsPC98Japanese };

static const char *const kEoB1Npc21StringsPC98Japanese[2] = {
	"\x90""\\""\x82\xb5\x8f""o""\x82\xf0\x95\xb7\x82\xad",
	"\x97\xa7\x82\xbf\x8b\x8e\x82\xe9"
};

static const StringListProvider kEoB1Npc21StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc21StringsPC98Japanese), kEoB1Npc21StringsPC98Japanese };

static const char *const kEoB1Npc22StringsPC98Japanese[2] = {
	"\x8f\x95\x82\xaf\x82\xe9",
	"\x97\xa7\x82\xbf\x8b\x8e\x82\xe9"
};

static const StringListProvider kEoB1Npc22StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc22StringsPC98Japanese), kEoB1Npc22StringsPC98Japanese };

static const char *const kEoB1Npc31StringsPC98Japanese[2] = {
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcc\x8f\x9d\x82\xf0\x96\xfc\x82\xb7",
	"\x97\xa7\x82\xbf\x8b\x8e\x82\xe9"
};

static const StringListProvider kEoB1Npc31StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc31StringsPC98Japanese), kEoB1Npc31StringsPC98Japanese };

static const char *const kEoB1Npc32StringsPC98Japanese[3] = {
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcc\x8f\x9d\x82\xf0\x96\xfc\x82\xb7",
	"\x8e\x80\x8e\xd2\x82\xf0\x95\x9c\x8a\x88\x82\xb3\x82\xb9\x82\xe9",
	"\x97\xa7\x82\xbf\x8b\x8e\x82\xe9"
};

static const StringListProvider kEoB1Npc32StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc32StringsPC98Japanese), kEoB1Npc32StringsPC98Japanese };

static const char *const kEoB1Npc4StringsPC98Japanese[2] = {
	"\x8d""U""\x8c\x82\x82\xb7\x82\xe9",
	"\x98""d""\x98""G""\x82\xf0\x93""n""\x82\xb7"
};

static const StringListProvider kEoB1Npc4StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc4StringsPC98Japanese), kEoB1Npc4StringsPC98Japanese };

static const char *const kEoB1Npc5StringsPC98Japanese[3] = {
	"\x8e""E""\x82\xb7",
	"\x98""b""\x82\xf0\x8d\xc5\x8c\xe3\x82\xdc\x82\xc5\x95\xb7\x82\xad",
	"\x8d""s""\x82\xa9\x82\xb9\x82\xe9"
};

static const StringListProvider kEoB1Npc5StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc5StringsPC98Japanese), kEoB1Npc5StringsPC98Japanese };

static const char *const kEoB1Npc6StringsPC98Japanese[2] = {
	"\x8d""~""\x95\x9a\x82\xb7\x82\xe9",
	"\x8d""U""\x8c\x82\x82\xb7\x82\xe9"
};

static const StringListProvider kEoB1Npc6StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc6StringsPC98Japanese), kEoB1Npc6StringsPC98Japanese };

static const char *const kEoB1Npc7StringsPC98Japanese[3] = {
	"\x8e\xa9\x97""R""\x82\xc9\x82\xb7\x82\xe9",
	"\x8e""E""\x82\xb7",
	"\x97\xa7\x82\xbf\x8b\x8e\x82\xe9"
};

static const StringListProvider kEoB1Npc7StringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1Npc7StringsPC98Japanese), kEoB1Npc7StringsPC98Japanese };

static const char *const kEoB1PryDoorStringsPC98Japanese[7] = {
	"\x97\xcd\x82\xf0\x82\xd3\x82\xe8\x82\xb5\x82\xda\x82\xc1\x82\xbd\x82\xaa\x92""N""\x82\xc9\x82\xe0\x94\xe0\x82\xcd\x8a""J""\x82\xaf\x82\xe7\x82\xea\x82\xc8\x82\xa9\x82\xc1\x82\xbd\x81""B\r",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x82\xcd\x97\xcd\x82\xc3\x82\xad\x82\xc5\x94\xe0\x82\xf0\x8a""J""\x82\xaf\x82\xbd\x81""B\r",
	"%s""\x82\xcd\x97\xcd\x82\xc3\x82\xad\x82\xc5\x94\xe0\x82\xf0\x8a""J""\x82\xaf\x82\xbd\x81""I\r",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcd\x97\xcd\x82\xc3\x82\xad\x82\xc5\x94\xe0\x82\xf0\x8a""J""\x82\xaf\x82\xe6\x82\xa4\x82\xc6\x82\xb5\x82\xc4\x8e\xb8\x94""s""\x82\xb5\x82\xbd\x81""B\r",
	"\x82\xbb\x82\xcc\x83""A""\x83""C""\x83""e""\x83\x80\x82\xcd\x82\xbb\x82\xb1\x82\xc9\x92""u""\x82\xad\x82\xb1\x82\xc6\x82\xcd\x82\xc5\x82\xab\x82\xc8\x82\xa2\x81""B\r",
	"\x82\xbb\x82\xcc\x83""A""\x83""C""\x83""e""\x83\x80\x82\xc5\x82\xcd\x91\xe5\x82\xab\x82\xb7\x82\xac\x82\xe9\x81""B\r",
	"\x92""N""\x82\xc9\x82\xe0\x82\xb1\x82\xcc\x94\xe0\x82\xf0\x8a""J""\x82\xaf\x82\xe9\x82\xb1\x82\xc6\x82\xcd\x82\xc5\x82\xab\x82\xc8\x82\xa2\x81""B\r"
};

static const StringListProvider kEoB1PryDoorStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1PryDoorStringsPC98Japanese), kEoB1PryDoorStringsPC98Japanese };

static const char *const kEoB1WarningStringsPC98Japanese[3] = {
	"\x82\xbb\x82\xcc\x95\xfb\x8c\xfc\x82\xd6\x82\xcd\x90""i""\x82\xdf\x82\xc8\x82\xa2\x81""B\r",
	"%s""\x82\xcd\x90""H""\x97\xbf\x82\xf0\x90""H""\x82\xd7\x82\xe9\x82\xb1\x82\xc6\x82\xaa\x8f""o""\x97\x88\x82\xc8\x82\xa2\x81""I\r",
	"\x8c\xfb\x82\xc9\x82\xc5\x82\xab\x82\xe9\x82\xcc\x82\xcd\x90""H""\x82\xd7\x82\xe0\x82\xcc\x82\xbe\x82\xaf\x82\xbe\x81""B\r"
};

static const StringListProvider kEoB1WarningStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1WarningStringsPC98Japanese), kEoB1WarningStringsPC98Japanese };

static const char *const kEoB1ItemNamesPC98Japanese[96] = {
	"\x83""}""\x83""E""\x83""X",
	"",
	"\x83\x8c\x83""U""\x81""[""\x81""E""\x83""A""\x81""[""\x83""}""\x81""[",
	"\x83\x8d\x81""[""\x83""u",
	"\x83""X""\x83""^""\x83""b""\x83""t",
	"\x83""_""\x83""K""\x81""[",
	"\x83""V""\x83\x87\x81""[""\x83""g""\x83""\\""\x81""[""\x83""h",
	"\x8c\xae\x8a""J""\x82\xaf\x93\xb9\x8b\xef",
	"\x8e\xf4\x95\xb6\x8f\x91",
	"\x91""m""\x97\xb5\x82\xcc\x83""z""\x81""[""\x83\x8a\x81""[""\x81""E""\x83""V""\x83\x93\x83""{""\x83\x8b",
	"\x83\x8c\x83""U""\x81""[""\x81""E""\x83""u""\x81""[""\x83""c",
	"\x8c""g""\x8d""s""\x90""H""\x97\xbf",
	"\x82\xc8\x82\xc9\x82\xe0\x82\xc8\x82\xa2",
	"\x95\xf3\x90\xce\x82\xcc\x8c\xae",
	"\x83""|""\x81""[""\x83""V""\x83\x87\x83\x93",
	"\x95\xf3\x90\xce",
	"\x82\xc7\x82\xad\x82\xeb\x82\xcc\x8c\xae",
	"\x83\x8f\x83\x93\x83""h",
	"\x83""X""\x83""N""\x83\x8d\x81""[""\x83\x8b",
	"\x83\x8a\x83\x93\x83""O",
	"\x96""h""\x8c\xec\x82\xcc\x83\x8a\x83\x93\x83""O""\x81""{""\x82""Q",
	"\x83""A""\x83""_""\x83""}""\x83\x93\x83""^""\x83""C""\x83""g""\x81""E""\x83""_""\x81""[""\x83""c",
	"\x90\xb9\x8b""R""\x8e""m""\x82\xcc\x83""z""\x81""[""\x83\x8a\x81""[""\x81""E""\x83""V""\x83\x93\x83""{""\x83\x8b",
	"\x83""V""\x83\x8b\x83\x94\x83""B""\x83""A""\x82\xcc\x83\x8f\x83\x93\x83""h",
	"\x83""h""\x83\x8f\x81""[""\x83""t""\x82\xcc\x8d\x9c",
	"\x8c\xae",
	"\x88\xcf\x94""C""\x8f\xf3\x82\xa9\x82\xc2\x96\xc6\x8b\x96\x8f\xf3",
	"\x83""A""\x83""b""\x83""N""\x83""X",
	"\x83""_""\x81""[""\x83""c",
	"\x83""n""\x83\x8b\x83""o""\x81""[""\x83""h",
	"\x83""`""\x83""F""\x83""C""\x83\x93\x83\x81\x83""C""\x83\x8b",
	"\x83""w""\x83\x8b\x83\x81\x83""b""\x83""g",
	"\x83""h""\x83\x8f\x81""[""\x83""t""\x81""E""\x83""w""\x83\x8b\x83\x81\x83""b""\x83""g",
	"\x8b\xe2\x82\xcc\x8c\xae",
	"\x83""A""\x83""_""\x83""}""\x83\x93\x83""^""\x83""C""\x83""g""\x81""E""\x83\x8d\x83\x93\x83""O""\x81""E""\x83""\\""\x81""[""\x83""h",
	"\x83\x81\x83""C""\x83""X",
	"\x83\x8d\x83\x93\x83""O""\x81""E""\x83""\\""\x81""[""\x83""h",
	"\x81""h""\x83""O""\x83""C""\x83\x93\x83""X""\x81""[""\x81""h",
	"\x97\xcd\x82\xcc\x83""I""\x81""[""\x83""u",
	"\x83""h""\x83\x8f\x81""[""\x83""t""\x82\xcc\x83""q""\x81""[""\x83\x8a\x83\x93\x83""O""\x83""|""\x81""[""\x83""V""\x83\x87\x83\x93",
	"\x90\xce",
	"\x90""H""\x97\xbf",
	"\x94\xfc\x97\xed\x82\xc8\x83\x8d\x81""[""\x83""u",
	"\x89\xce\x90\xac\x8a\xe2",
	"\x83""X""\x83""s""\x83""A",
	"\x94\xe9\x90\xce\x82\xcc\x83\x81\x83""_""\x83\x8a\x83""I""\x83\x93",
	"\x83""n""\x81""[""\x83""t""\x83\x8a\x83\x93\x83""O""\x82\xcc\x8d\x9c",
	"\x83""A""\x83\x8d\x81""[",
	"\x83""V""\x81""[""\x83\x8b\x83""h",
	"\x8b\xe0\x82\xcc\x8c\xae",
	"\x83""{""\x83""E",
	"\x94\xe9\x90\xce\x82\xcc\x83""_""\x83""K""\x81""[",
	"\x83""X""\x83\x8a\x83\x93\x83""O",
	"\x83""o""\x83""b""\x83""N""\x83""X""\x83""^""\x83""b""\x83""o""\x81""[",
	"\x83\x8d\x83\x93\x83""O""\x83""\\""\x81""[""\x83""h",
	"\x83""h""\x83\x8f\x81""[""\x83""t""\x82\xcc\x8c\xae",
	"\x83\x81\x83""_""\x83\x8a\x83""I""\x83\x93",
	"\x91\x95\x8f\xfc\x82\xcc\x83\x81\x83""_""\x83\x8a\x83""I""\x83\x93",
	"\x83""h""\x83\x8d\x83""E""\x81""E""\x83""N""\x83\x8c\x81""[""\x83""o""\x81""[",
	"\x94\xe9\x90\xce\x82\xcc\x83""Z""\x83""v""\x83""^""\x81""[",
	"\x83""h""\x83\x8f\x81""[""\x83""t""\x81""E""\x83""w""\x83\x8b\x83\x81\x83""b""\x83""g",
	"\x83""h""\x83\x8f\x81""[""\x83""t""\x81""E""\x83""V""\x81""[""\x83\x8b\x83""h",
	"\x94\xe9\x90\xce\x82\xcc\x83""l""\x83""b""\x83""N""\x83\x8c\x83""X",
	"\x83""v""\x83\x8c\x81""[""\x83""g""\x81""E""\x83\x81\x83""C""\x83\x8b",
	"\x83""X""\x83""P""\x81""[""\x83\x8b\x81""E""\x83\x81\x83""C""\x83\x8b",
	"\x83""u""\x81""[""\x83""c",
	"\x83""P""\x83\x93\x83""N""\x82\xcc\x97\x91",
	"\x94\xe9\x90\xce\x82\xcc\x83\x8a\x83\x93\x83""O",
	"\x83""u""\x83\x8c\x81""[""\x83""T""\x81""[",
	"\x83""`""\x81""[""\x83""t""\x83""e""\x83\x93\x81""E""\x83""n""\x83\x8b\x83""o""\x81""[""\x83""h",
	"\x83""l""\x83""b""\x83""N""\x83\x8c\x83""X",
	"\x91\x95\x8f\xfc\x82\xcc\x83""l""\x83""b""\x83""N""\x83\x8c\x83""X",
	"\x8d""K""\x89""^""\x82\xcc\x90\xce\x82\xcc\x83\x81\x83""_""\x83\x8a\x83""I""\x83\x93",
	"\x81""h""\x83""X""\x83\x89\x83""C""\x83""T""\x81""[""\x81""h",
	"\x83""o""\x83\x93\x83""f""\x83""B""\x83""b""\x83""h""\x81""E""\x83""A""\x81""[""\x83""}""\x81""[",
	"\x83""h""\x83\x8d\x83""E""\x82\xcc\x8c\xae",
	"\x83\x8b\x83""r""\x81""[""\x82\xcc\x8c\xae",
	"\x81""h""\x83""i""\x83""C""\x83""g""\x81""E""\x83""X""\x83""g""\x81""[""\x83""J""\x81""[""\x81""h",
	"\x83""h""\x83\x8d\x83""E""\x81""E""\x83""{""\x83""E",
	"\x83""h""\x83\x8d\x83""E""\x81""E""\x83""u""\x81""[""\x83""c",
	"\x89\xd8\x97\xed\x82\xcc\x83""v""\x83\x8c\x81""[""\x83""g""\x81""E""\x83\x81\x83""C""\x83\x8b",
	"\x83""t""\x83\x8c\x83""C""\x83\x8b",
	"\x89\xa4\x8e\xd2\x82\xcc\x97\xcd\x82\xcc\x83""Z""\x83""v""\x83""^""\x81""[",
	"\x83""h""\x83\x8d\x83""E""\x81""E""\x83""V""\x81""[""\x83\x8b\x83""h",
	"\x94\xe9\x90\xce\x82\xcc\x83""z""\x81""[""\x83\x8a\x81""[""\x81""E""\x83""V""\x83\x93\x83""{""\x83\x8b",
	"\x94\xe9\x90\xce\x82\xcc\x83""I""\x81""[""\x83""u",
	"\x81""h""\x83""X""\x83\x89\x83""b""\x83""V""\x83\x83\x81""[""\x81""h",
	"\x8e\xe7\x82\xe8\x82\xcc\x83\x8d\x81""[""\x83""u",
	"\x81""h""\x83""t""\x83\x8a\x83""b""\x83""J""\x81""h",
	"\x90""l""\x8a\xd4\x82\xcc\x8d\x9c",
	"\x81""h""\x83""V""\x83\x94\x83""@""\x83\x8a\x83""A""\x83""X""\x81""h",
	"\x89\xce\x8b\x85\x82\xcc\x83\x8f\x83\x93\x83""h",
	"\x89\xf0\x93\xc5\x82\xcc\x83""|""\x81""[""\x83""V""\x83\x87\x83\x93",
	"\x83""z""\x81""[""\x83\x8a\x81""[""\x81""E""\x83""V""\x83\x93\x83""{""\x83\x8b",
	"\x8e\xf4\x95\xb6\x8f\x91",
	""
};

static const StringListProvider kEoB1ItemNamesPC98JapaneseProvider = { ARRAYSIZE(kEoB1ItemNamesPC98Japanese), kEoB1ItemNamesPC98Japanese };

static const char *const kEoB1ItemSuffixStringsRingsPC98Japanese[4] = {
	"\x83""A""\x83""h""\x81""[""\x83\x93\x83\x81\x83\x93\x83""g",
	"\x83""E""\x83""B""\x83""U""\x81""[""\x83""h""\x83\x8a\x83""B",
	"\x83""T""\x83""X""\x83""e""\x83""i""\x83\x93\x83""X",
	"\x83""t""\x83""F""\x83""U""\x81""[""\x81""E""\x83""t""\x83""H""\x81""[""\x83\x8b"
};

static const StringListProvider kEoB1ItemSuffixStringsRingsPC98JapaneseProvider = { ARRAYSIZE(kEoB1ItemSuffixStringsRingsPC98Japanese), kEoB1ItemSuffixStringsRingsPC98Japanese };

static const char *const kEoB1ItemSuffixStringsPotionsPC98Japanese[8] = {
	"\x83""W""\x83\x83\x83""C""\x83""A""\x83\x93\x83""g""\x81""E""\x83""X""\x83""g""\x83\x8c\x83\x93\x83""O""\x83""X",
	"\x83""q""\x81""[""\x83\x8a\x83\x93\x83""O",
	"\x83""G""\x83""N""\x83""X""\x83""g""\x83\x89\x81""E""\x83""q""\x81""[""\x83\x8a\x83\x93\x83""O",
	"\x83""|""\x83""C""\x83""Y""\x83\x93",
	"\x83""o""\x83""C""\x83""^""\x83""C""\x83""e""\x83""B",
	"\x83""X""\x83""s""\x81""[""\x83""h",
	"\x83""C""\x83\x93\x83""r""\x83""W""\x83""r""\x83\x8a\x83""e""\x83""B",
	"\x83""L""\x83\x85\x83""A""\x81""E""\x83""|""\x83""C""\x83""Y""\x83\x93"
};

static const StringListProvider kEoB1ItemSuffixStringsPotionsPC98JapaneseProvider = { ARRAYSIZE(kEoB1ItemSuffixStringsPotionsPC98Japanese), kEoB1ItemSuffixStringsPotionsPC98Japanese };

static const char *const kEoB1ItemSuffixStringsWandsPC98Japanese[7] = {
	"\x83""X""\x83""e""\x83""B""\x83""b""\x83""N",
	"\x83\x89\x83""C""\x83""g""\x83""j""\x83\x93\x83""O""\x81""E""\x83""{""\x83\x8b\x83""g",
	"\x83""t""\x83\x8d\x83""X""\x83""g",
	"\x83""L""\x83\x85\x83""A""\x83\x8a\x83\x93\x83""O",
	"\x83""t""\x83""@""\x83""C""\x83""A""\x83""{""\x81""[""\x83\x8b",
	"\x83""V""\x83\x8b\x83\x94\x83""B""\x83""A",
	"\x83""}""\x83""W""\x83""b""\x83""N""\x81""E""\x83""~""\x83""T""\x83""C""\x83\x8b"
};

static const StringListProvider kEoB1ItemSuffixStringsWandsPC98JapaneseProvider = { ARRAYSIZE(kEoB1ItemSuffixStringsWandsPC98Japanese), kEoB1ItemSuffixStringsWandsPC98Japanese };

static const char *const kEoB1RipItemStringsPC98Japanese[3] = {
	"%s""\x82\xcd",
	"%s""\x82\xcd",
	"\x82\xf0\x82\xc8\x82\xad\x82\xb5\x82\xbd\x81""B\r"
};

static const StringListProvider kEoB1RipItemStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1RipItemStringsPC98Japanese), kEoB1RipItemStringsPC98Japanese };

static const char *const kEoB1CursedStringPC98Japanese[1] = {
	"\x8e\xf4\x82\xed\x82\xea\x82\xc4\x82\xa2\x82\xe9""%s%d"
};

static const StringListProvider kEoB1CursedStringPC98JapaneseProvider = { ARRAYSIZE(kEoB1CursedStringPC98Japanese), kEoB1CursedStringPC98Japanese };

static const char *const kEoB1MagicObjectStringsPC98Japanese[5] = {
	"\x96\x82\x96""@""\x8e""g""\x82\xa2\x97""p""\x8a\xaa\x95\xa8",
	"\x91""m""\x97\xb5\x97""p""\x8a\xaa\x95\xa8",
	"\x83\x8a\x83\x93\x83""O",
	"\x83""|""\x81""[""\x83""V""\x83\x87\x83\x93",
	"\x83\x8f\x83\x93\x83""h"
};

static const StringListProvider kEoB1MagicObjectStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1MagicObjectStringsPC98Japanese), kEoB1MagicObjectStringsPC98Japanese };

static const char *const kEoB1MagicObjectString5PC98Japanese[1] = {
	"\x83""X""\x83""e""\x83""B""\x83""b""\x83""N"
};

static const StringListProvider kEoB1MagicObjectString5PC98JapaneseProvider = { ARRAYSIZE(kEoB1MagicObjectString5PC98Japanese), kEoB1MagicObjectString5PC98Japanese };

static const char *const kEoB1PatternSuffixPC98Japanese[1] = {
	"%s""\x82\xcc""%s"
};

static const StringListProvider kEoB1PatternSuffixPC98JapaneseProvider = { ARRAYSIZE(kEoB1PatternSuffixPC98Japanese), kEoB1PatternSuffixPC98Japanese };

static const char *const kEoB1PatternGrFix1PC98Japanese[1] = {
	"%s""\x82\xcc""%s"
};

static const StringListProvider kEoB1PatternGrFix1PC98JapaneseProvider = { ARRAYSIZE(kEoB1PatternGrFix1PC98Japanese), kEoB1PatternGrFix1PC98Japanese };

static const char *const kEoB1PatternGrFix2PC98Japanese[1] = {
	"%s""\x82\xcc""%s"
};

static const StringListProvider kEoB1PatternGrFix2PC98JapaneseProvider = { ARRAYSIZE(kEoB1PatternGrFix2PC98Japanese), kEoB1PatternGrFix2PC98Japanese };

static const char *const kEoB1ValidateArmorStringPC98Japanese[1] = {
	"%s""\x82\xcd\x82\xbb\x82\xcc\x83""^""\x83""C""\x83""v""\x82\xcc\x96""h""\x8b\xef\x82\xf0\x90""g""\x82\xc9\x82\xc2\x82\xaf\x82\xe7\x82\xea\x82\xc8\x82\xa2\x81""B\r"
};

static const StringListProvider kEoB1ValidateArmorStringPC98JapaneseProvider = { ARRAYSIZE(kEoB1ValidateArmorStringPC98Japanese), kEoB1ValidateArmorStringPC98Japanese };

static const char *const kEoB1ValidateNoDropStringPC98Japanese[1] = {
	"\x82\xbb\x82\xcc\x83""A""\x83""C""\x83""e""\x83\x80\x82\xf0\x82\xbb\x82\xb1\x82\xc9\x92""u""\x82\xad\x82\xb1\x82\xc6\x82\xcd\x82\xc5\x82\xab\x82\xc8\x82\xa2\x81""B\r"
};

static const StringListProvider kEoB1ValidateNoDropStringPC98JapaneseProvider = { ARRAYSIZE(kEoB1ValidateNoDropStringPC98Japanese), kEoB1ValidateNoDropStringPC98Japanese };

static const char *const kEoB1PotionStringsPC98Japanese[2] = {
	"\x93\xc5\x82\xf0\x8e\xf3\x82\xaf\x82\xbd",
	"%s""\x82\xcd""%s""\x81""I\r"
};

static const StringListProvider kEoB1PotionStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1PotionStringsPC98Japanese), kEoB1PotionStringsPC98Japanese };

static const char *const kEoB1WandStringsPC98Japanese[2] = {
	"\x82\xbb\x82\xcc\x83\x8f\x83\x93\x83""h""\x82\xc9\x96\x82\x96""@""\x82\xcc\x8c\xf8\x89\xca\x82\xcd\x82\xc8\x82\xa2\x82\xe6\x82\xa4\x82\xbe\x81""B\r",
	"\x8c\xf8\x89\xca\x82\xcd\x82\xc8\x82\xa9\x82\xc1\x82\xbd\x81""B\r"
};

static const StringListProvider kEoB1WandStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1WandStringsPC98Japanese), kEoB1WandStringsPC98Japanese };

static const char *const kEoB1ItemMisuseStringsPC98Japanese[3] = {
	"%s""\x82\xcd\x82\xb1\x82\xcc\x83""A""\x83""C""\x83""e""\x83\x80\x82\xf0\x8e""g""\x82\xa4\x82\xb1\x82\xc6\x82\xaa\x82\xc5\x82\xab\x82\xc8\x82\xa2\x81""B\r",
	"\x82\xb1\x82\xcc\x83""A""\x83""C""\x83""e""\x83\x80\x82\xcd\x91\x95\x94\xf5\x82\xb7\x82\xea\x82\xce\x8e\xa9\x93\xae\x93""I""\x82\xc9\x8c\xf8\x89\xca\x82\xf0\x8e\x9d\x82\xc2\x81""B\r",
	"\x83""A""\x83""C""\x83""e""\x83\x80\x82\xcc\x8e""g""\x82\xa2\x95\xfb\x82\xaa\x8a\xd4\x88\xe1\x82\xc1\x82\xc4\x82\xa2\x82\xe9\x81""B\r"
};

static const StringListProvider kEoB1ItemMisuseStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1ItemMisuseStringsPC98Japanese), kEoB1ItemMisuseStringsPC98Japanese };

static const char *const kEoB1TakenStringsPC98Japanese[1] = {
	"\x82\xf0\x8e\xe8\x82\xc9\x8e\xe6\x82\xc1\x82\xbd\x81""B\r"
};

static const StringListProvider kEoB1TakenStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1TakenStringsPC98Japanese), kEoB1TakenStringsPC98Japanese };

static const char *const kEoB1PotionEffectStringsPC98Japanese[8] = {
	"\x97\xcd\x82\xaa\x82\xa0\x82\xaa\x82\xc1\x82\xbd",
	"\x8c\xb3\x8b""C""\x82\xc9\x82\xc8\x82\xc1\x82\xbd",
	"\x82\xb8\x82\xc1\x82\xc6\x8c\xb3\x8b""C""\x82\xc9\x82\xc8\x82\xc1\x82\xbd",
	"\x82\xb5\x82\xce\x82\xe7\x82\xad\x8b""C""\x95\xaa\x82\xaa\x88\xab\x82\xad\x82\xc8\x82\xc1\x82\xbd",
	"\x82\xe0\x82\xcd\x82\xe2\x8b\xf3\x95\xa0\x82\xc5\x82\xcd\x82\xc8\x82\xad\x82\xc8\x82\xc1\x82\xbd",
	"\x82\xb7\x82\xce\x82\xe2\x82\xad\x8b""@""\x95""q""\x82\xc9\x82\xc8\x82\xc1\x82\xbd",
	"\x93\xa7\x96\xbe\x82\xc9\x82\xc8\x82\xc1\x82\xbd",
	"\x8b""C""\x95\xaa\x82\xaa\x82\xe6\x82\xad\x82\xc8\x82\xc1\x82\xbd"
};

static const StringListProvider kEoB1PotionEffectStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1PotionEffectStringsPC98Japanese), kEoB1PotionEffectStringsPC98Japanese };

static const char *const kEoB1YesNoStringsPC98Japanese[2] = {
	"\x82\xcd\x82\xa2",
	"\x82\xa2\x82\xa2\x82\xa6"
};

static const StringListProvider kEoB1YesNoStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1YesNoStringsPC98Japanese), kEoB1YesNoStringsPC98Japanese };

static const char *const kEoB1MoreStringsPC98Japanese[1] = {
	"\x8e\x9f\x82\xd6"
};

static const StringListProvider kEoB1MoreStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1MoreStringsPC98Japanese), kEoB1MoreStringsPC98Japanese };

static const char *const kEoB1NpcMaxStringsPC98Japanese[1] = {
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xc9\x93\xfc\x82\xea\x82\xe7\x82\xea\x82\xe9\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xcd\x82""U""\x90""l""\x82\xdc\x82\xc5\x82\xc5\x82\xb7\x81""B\r""\x82\xcd\x82\xb8\x82\xb5\x82\xbd\x82\xa2\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xf0\x82""P""\x90""l""\x91""I""\x82\xf1\x82\xc5\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""B"
};

static const StringListProvider kEoB1NpcMaxStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1NpcMaxStringsPC98Japanese), kEoB1NpcMaxStringsPC98Japanese };

static const char *const kEoB1NpcJoinStringsPC98Japanese[1] = {
	"%s""\x82\xaa\x83""p""\x81""[""\x83""e""\x83""B""\x82\xc9\x89\xc1\x82\xed\x82\xc1\x82\xbd\x81""B\r"
};

static const StringListProvider kEoB1NpcJoinStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1NpcJoinStringsPC98Japanese), kEoB1NpcJoinStringsPC98Japanese };

static const char *const kEoB1CancelStringsPC98Japanese[1] = {
	"\x82\xe2\x82\xdf\x82\xe9"
};

static const StringListProvider kEoB1CancelStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1CancelStringsPC98Japanese), kEoB1CancelStringsPC98Japanese };

static const char *const kEoB1MenuStringsMainPC98Japanese[8] = {
	"\x91""I""\x91\xf0\x83""R""\x83""}""\x83\x93\x83""h""\x81""F",
	"\x8b""x""\x91\xa7\x82\xb7\x82\xe9",
	"\x8e\xf4\x95\xb6\x82\xf0\x8b""L""\x89\xaf\x82\xb7\x82\xe9",
	"\x8e\xf4\x95\xb6\x82\xf0\x8e\xf6\x82\xa9\x82\xe9",
	"\x8e\xf4\x95\xb6\x82\xf0\x8f\x91\x82\xab\x82\xb1\x82\xde",
	"\x83""Q""\x81""[""\x83\x80\x8a\xc2\x8b\xab",
	"\x95\xe2\x8f\x95\x8b""@""\x94""\\",
	"\x94\xb2\x82\xaf\x82\xe9"
};

static const StringListProvider kEoB1MenuStringsMainPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsMainPC98Japanese), kEoB1MenuStringsMainPC98Japanese };

static const char *const kEoB1MenuStringsSaveLoadPC98Japanese[8] = {
	"\x83""Q""\x81""[""\x83\x80\x8f\xee\x95\xf1\x82\xf0\x93\xc7\x82\xdd\x82\xb1\x82\xde",
	"\x83""Q""\x81""[""\x83\x80\x8f\xee\x95\xf1\x82\xf0\x95\xdb\x91\xb6\x82\xb7\x82\xe9",
	"\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xf0\x82\xcd\x82\xb8\x82\xb7",
	"\x83""Q""\x81""[""\x83\x80\x82\xf0\x92\x86\x92""f""\x82\xb7\x82\xe9",
	"\x95\xe2\x8f\x95\x8b""@""\x94""\\""\x81""F",
	"\r   ""\x8f\x91\x82\xab\x82\xb1\x82\xdd\x82\xdc\x82\xb5\x82\xbd\x81""B",
	"\r ""\x83""Q""\x81""[""\x83\x80\x8f\xee\x95\xf1\x82\xf0\x8f\x91\x82\xab\x82\xb1\x82\xde""\r ""\x8e\xb8\x94""s""\x82\xb5\x82\xdc\x82\xb5\x82\xbd\x81""I",
	"\r ""\x83""Q""\x81""[""\x83\x80\x8f\xee\x95\xf1\x82\xf0\x93\xc7\x82\xdd\x82\xb1\x82\xde""\r ""\x8e\xb8\x94""s""\x82\xb5\x82\xdc\x82\xb5\x82\xbd\x81""I"
};

static const StringListProvider kEoB1MenuStringsSaveLoadPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsSaveLoadPC98Japanese), kEoB1MenuStringsSaveLoadPC98Japanese };

static const char *const kEoB1MenuStringsOnOffPC98Japanese[2] = {
	"\x82""n""\x82""m",
	"\x82""n""\x82""e""\x82""e"
};

static const StringListProvider kEoB1MenuStringsOnOffPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsOnOffPC98Japanese), kEoB1MenuStringsOnOffPC98Japanese };

static const char *const kEoB1MenuStringsSpellsPC98Japanese[17] = {
	"\r\r""\x8e\xf4\x95\xb6\x82\xf0\x8b""L""\x89\xaf\x82\xb3\x82\xb9\x82\xbd\x82\xa2\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xf0""\r""\x91""I""\x82\xf1\x82\xc5\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""B",
	"\r""\x82\xbb\x82\xcc\x90\xb9\x8b""R""\x8e""m""\x82\xcc\x83\x8c\x83""x""\x83\x8b\x82\xc5\x82\xcd\x82\xdc\x82\xbe\x8e\xf4\x95\xb6\x82\xcd\x8e""g""\x82\xa6\x82\xdc\x82\xb9\x82\xf1\x81""B",
	"\r\r""\x82\xbb\x82\xcc\x96\x82\x96""@""\x8e""g""\x82\xa2\x82\xcd\x8e\xf4\x95\xb6\x8f\x91\x82\xf0\x8e\x9d\x82\xc1\x82\xc4\x82\xa2\x82\xdc\x82\xb9\x82\xf1\x81""I",
	"\r\r\r""\x8e\xf4\x95\xb6\x82\xf0\x82\xb3\x82\xb8\x82\xa9\x82\xe7\x82\xb9\x82\xbd\x82\xa2\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xf0""\r""\x91""I""\x82\xf1\x82\xc5\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""B",
	"\r""\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xc9\x8e\xf4\x95\xb6\x82\xf0\x82\xb3\x82\xb8\x82\xa9\x82\xe9\x82\xb1\x82\xc6\x82\xcc\x82\xc5\x82\xab\x82\xe9\x91""m""\x97\xb5\x82\xcd\x82\xa2\x82\xdc\x82\xb9\x82\xf1\x81""B",
	"\r""\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xc9\x8e\xf4\x95\xb6\x82\xf0\x8b""L""\x89\xaf\x82\xb7\x82\xe9\x82\xb1\x82\xc6\x82\xcc\x82\xc5\x82\xab\x82\xe9\x96\x82\x96""@""\x8e""g""\x82\xa2\x82\xcd\x82\xa2\x82\xdc\x82\xb9\x82\xf1\x81""B",
	"\x8b""C""\x90\xe2\x82\xe0\x82\xb5\x82\xad\x82\xcd\x8e\x80\x82\xf1\x82\xbe\x8f\xf3\x91\xd4\x82\xcc\x96\x82\x96""@""\x8e""g""\x82\xa2\x82\xaa\x8e\xf4\x95\xb6\x82\xf0\x8b""L""\x89\xaf\x82\xb7\x82\xe9\x82\xb1\x82\xc6\x82\xcd\x82\xc5\x82\xab\x82\xdc\x82\xb9\x82\xf1\x81""B",
	"\x8b""C""\x90\xe2\x82\xe0\x82\xb5\x82\xad\x82\xcd\x8e\x80\x82\xf1\x82\xbe\x8f\xf3\x91\xd4\x82\xcc\x91""m""\x97\xb5\x82\xaa\x8e\xf4\x95\xb6\x82\xf0\x82\xb3\x82\xb8\x82\xa9\x82\xe9\x82\xb1\x82\xc6\x82\xcd\x82\xc5\x82\xab\x82\xdc\x82\xb9\x82\xf1\x81""B",
	"\x82""P",
	"\x82""Q",
	"\x82""R",
	"\x82""S",
	"\x82""T",
	"\x8c\x88\x82\xdf\x92\xbc\x82\xb5",
	"\x8e""g""\x82\xa6\x82\xe9\x8e\xf4\x95\xb6\x81""F",
	"\x82\xcd\x82\xa2",
	"\x82\xa2\x82\xa2\x82\xa6"
};

static const StringListProvider kEoB1MenuStringsSpellsPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsSpellsPC98Japanese), kEoB1MenuStringsSpellsPC98Japanese };

static const char *const kEoB1MenuStringsRestPC98Japanese[5] = {
	"\r""\x96\xfc\x82\xb5\x8e\xe8\x82\xc9\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcc\x8e\xa1\x97\xc3\x82\xf0\x82\xb3\x82\xb9\x82\xdc\x82\xb7\x82\xa9\x81""H",
	"\x8f\x9d\x82\xf0\x95\x89\x82\xc1\x82\xbd\x82\xdc\x82\xdc\x82\xcc\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xaa\x82\xa2\x82\xdc\x82\xb7\x81""B\r""\x82\xb3\x82\xe7\x82\xc9\x8b""x""\x91\xa7\x82\xb5\x82\xdc\x82\xb7\x82\xa9\x81""H",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcd\x8b""x""\x91\xa7\x82\xb5\x82\xc4\x82\xa2\x82\xdc\x82\xb7\x81""B",
	"\r""\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xcd\x91""S""\x88\xf5\x81""A""\x8a\xae\x91""S""\x89\xf1\x95\x9c\x82\xb5\x82\xdc\x82\xb5\x82\xbd\x81""B",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcd\x8e\xf4\x95\xb6\x82\xf0\x8e""g""\x82\xa6\x82\xe9\x82\xe6\x82\xa4\x82\xc9\x82\xb7\x82\xe9\x82\xcc\x82\xc9\x8b""x""\x91\xa7\x82\xf0\x95""K""\x97""v""\x82\xc6\x82\xb5\x82\xc4\x82\xa2\x82\xdc\x82\xb7\x81""B"
};

static const StringListProvider kEoB1MenuStringsRestPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsRestPC98Japanese), kEoB1MenuStringsRestPC98Japanese };

static const char *const kEoB1MenuStringsDropPC98Japanese[1] = {
	"\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xaa\x82""R""\x90""l""\x88\xc8\x89\xba\x82\xc5\x82\xcd\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcd\x91""g""\x82\xdf\x82\xdc\x82\xb9\x82\xf1\x81""B"
};

static const StringListProvider kEoB1MenuStringsDropPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsDropPC98Japanese), kEoB1MenuStringsDropPC98Japanese };

static const char *const kEoB1MenuStringsExitPC98Japanese[1] = {
	"\x96""{""\x93\x96\x82\xc9\x83""Q""\x81""[""\x83\x80\x82\xf0\x82\xe2\x82\xdf\x82\xdc\x82\xb7\x82\xa9\x81""H"
};

static const StringListProvider kEoB1MenuStringsExitPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsExitPC98Japanese), kEoB1MenuStringsExitPC98Japanese };

static const char *const kEoB1MenuStringsStarvePC98Japanese[1] = {
	"\x8b\xf3\x95\xa0\x82\xc8\x8f\xf3\x91\xd4\x82\xcc\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xaa\x82\xa2\x82\xdc\x82\xb7\x81""B\r""\x82\xb1\x82\xcc\x82\xdc\x82\xdc\x8b""x""\x91\xa7\x82\xf0\x91\xb1\x82\xaf\x82\xdc\x82\xb7\x82\xa9\x81""H"
};

static const StringListProvider kEoB1MenuStringsStarvePC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsStarvePC98Japanese), kEoB1MenuStringsStarvePC98Japanese };

static const char *const kEoB1MenuStringsScribePC98Japanese[5] = {
	"\x8f\x91\x82\xab\x8e\xca\x82\xb5\x82\xbd\x82\xa2\x83""X""\x83""N""\x83\x8d\x81""[""\x83\x8b\x82\xf0\x91""I""\x82\xf1\x82\xc5\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""B",
	"\r\r\r""\x8e\xf4\x95\xb6\x82\xf0\x8f\x91\x82\xab\x8e\xca\x82\xb3\x82\xb9\x82\xbd\x82\xa2\x96\x82\x96""@""\x8e""g""\x82\xa2\x82\xf0\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xa9\x82\xe7\x91""I""\x82\xf1\x82\xc5\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""B",
	"\x8f\x91\x82\xab\x8e\xca\x82\xb9\x82\xe9\x83""X""\x83""N""\x83\x8d\x81""[""\x83\x8b\x82\xcd\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x93\xe0\x82\xc9\x82\xa0\x82\xe8\x82\xdc\x82\xb9\x82\xf1\x81""B",
	"\x82\xb1\x82\xcc\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xc9\x95""K""\x97""v""\x82\xc8\x83""X""\x83""N""\x83\x8d\x81""[""\x83\x8b\x82\xcd\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x93\xe0\x82\xc9\x82\xa0\x82\xe8\x82\xdc\x82\xb9\x82\xf1\x81""B",
	"\r""\x83""X""\x83""N""\x83\x8d\x81""[""\x83\x8b\x82\xf0\x8f\x91\x82\xab\x8e\xca\x82\xb7\x82\xb1\x82\xc6\x82\xcc\x82\xc5\x82\xab\x82\xe9\x96\x82\x96""@""\x8e""g""\x82\xa2\x82\xcd\x82\xa2\x82\xdc\x82\xb9\x82\xf1\x81""B"
};

static const StringListProvider kEoB1MenuStringsScribePC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsScribePC98Japanese), kEoB1MenuStringsScribePC98Japanese };

static const char *const kEoB1MenuStringsDrop2PC98Japanese[3] = {
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xa9\x82\xe7\x82\xcd\x82\xb8\x82\xb5\x82\xbd\x82\xa2\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xf0""\r""\x91""I""\x82\xf1\x82\xc5\x82\xad\x82\xbe\x82\xb3\x82\xa2\x81""B",
	"\x8c\xbb\x8d\xdd\x82\xcc\x83""Q""\x81""[""\x83\x80\x8f\xee\x95\xf1\x82\xf0\x95\xdb\x91\xb6\x82\xb5\x82\xdc\x82\xb7\x81""B\r""\x82\xa2\x82\xa2\x82\xc5\x82\xb7\x82\xa9\x81""H",
	"\x95\xdb\x91\xb6\x82\xb5\x82\xc4\x82\xa0\x82\xe9\x83""Q""\x81""[""\x83\x80\x8f\xee\x95\xf1\x82\xf0\x93\xc7\x82\xdd\x8d\x9e\x82\xdd\x82\xdc\x82\xb7\x81""B\r""\x82\xa2\x82\xa2\x82\xc5\x82\xb7\x82\xa9\x81""H"
};

static const StringListProvider kEoB1MenuStringsDrop2PC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsDrop2PC98Japanese), kEoB1MenuStringsDrop2PC98Japanese };

static const char *const kEoB1MenuStringsHeadPC98Japanese[3] = {
	"\x83""L""\x83\x83\x83\x93\x83""v""\x81""F",
	"\x91""I""\x91\xf0\x81""F",
	"\x95\xe2\x8f\x95\x8b""@""\x94""\\""\x81""F"
};

static const StringListProvider kEoB1MenuStringsHeadPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsHeadPC98Japanese), kEoB1MenuStringsHeadPC98Japanese };

static const char *const kEoB1MenuStringsPoisonPC98Japanese[1] = {
	"\x93\xc5\x82\xf0\x8e\xf3\x82\xaf\x82\xc4\x82\xa2\x82\xe9\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xaa\x8e\x80\x82\xf1\x82\xc5\x82\xb5""\r""\x82\xdc\x82\xa2\x82\xdc\x82\xb7\x81""I\r""\x82\xbb\x82\xea\x82\xc5\x82\xe0\x8b""x""\x91\xa7\x82\xb5\x82\xdc\x82\xb7\x82\xa9\x81""H"
};

static const StringListProvider kEoB1MenuStringsPoisonPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsPoisonPC98Japanese), kEoB1MenuStringsPoisonPC98Japanese };

static const char *const kEoB1MenuStringsMgcPC98Japanese[2] = {
	"%1d",
	"\x91\x8d\x8c""v%d""\x8c\xc2\x81""A""\x8e""c""\x82\xe8""%d""\x8c\xc2\x82\xf0\x91""I""\x82\xd7\x82\xdc\x82\xb7\x81""B""\x81""@""\x81""@"
};

static const StringListProvider kEoB1MenuStringsMgcPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsMgcPC98Japanese), kEoB1MenuStringsMgcPC98Japanese };

static const char *const kEoB1MenuStringsPrefsPC98Japanese[4] = {
	"\x89\xb9\x8a""y""\x81""@%-6s",
	"\x8c\xf8\x89\xca\x89\xb9\x81""@%-6s",
	"\x83""o""\x81""[""\x95""\\""\x8e\xa6\x81""@%-6s",
	"\x83""}""\x83""E""\x83""X""\x81""@%-6s"
};

static const StringListProvider kEoB1MenuStringsPrefsPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsPrefsPC98Japanese), kEoB1MenuStringsPrefsPC98Japanese };

static const char *const kEoB1MenuStringsRest2PC98Japanese[4] = {
	"%s""\x82\xcd""%s""\x82\xcc\x8e\xf4\x95\xb6\x82\xf0\x8e\xf6\x82\xa9\x82\xc1\x82\xbd\x81""B\r",
	"%s""\x82\xcd""%s""\x82\xcc\x8e\xf4\x95\xb6\x82\xf0\x8b""L""\x89\xaf\x82\xb5\x82\xbd\x81""B\r",
	"%s""\x82\xcd""%s""\x82\xc9\x8e\xa1\x96\xfc\x82\xcc\x8e\xf4\x95\xb6\x82\xf0\x82\xa9\x82\xaf\x82\xbd\x81""B\r",
	"\x8b""x""\x8c""e""\x8e\x9e\x8a\xd4\x81""F""\x81""@%-4d""\x81""@""\x81""@""\x81""@""\x81""@"
};

static const StringListProvider kEoB1MenuStringsRest2PC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsRest2PC98Japanese), kEoB1MenuStringsRest2PC98Japanese };

static const char *const kEoB1MenuStringsRest4PC98Japanese[1] = {
	"\r""\x82\xb1\x82\xb1\x82\xc5\x8b""x""\x91\xa7\x82\xb7\x82\xe9\x82\xb1\x82\xc6\x82\xcd\x82\xc5\x82\xab\x82\xc8\x82\xa2\x81""B""\x8b\xdf\x82\xad\x82\xc9\x83\x82\x83\x93\x83""X""\x83""^""\x81""[""\x82\xaa\x82\xa2\x82\xe9\x81""B\r"
};

static const StringListProvider kEoB1MenuStringsRest4PC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsRest4PC98Japanese), kEoB1MenuStringsRest4PC98Japanese };

static const char *const kEoB1MenuStringsDefeatPC98Japanese[1] = {
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcd\x91""S""\x96\xc5\x82\xb5\x82\xbd\x81""B\r\r""\x82\xb1\x82\xea\x82\xc5\x88\xab\x82\xcc\x88\xea\x96\xa1\x82\xcd\x8e\xd7\x96\x82\x82\xb3\x82\xea\x82\xe9\x82\xb1\x82\xc6\x82\xc8\x82\xad\x8c""v""\x89\xe6\x82\xf0\x8e\xc0\x8d""s""\x82\xc5\x82\xab\x82\xe9\x82\xbe\x82\xeb\x82\xa4\x81""B"
};

static const StringListProvider kEoB1MenuStringsDefeatPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuStringsDefeatPC98Japanese), kEoB1MenuStringsDefeatPC98Japanese };

static const char *const kEoB1MenuYesNoStringsPC98Japanese[2] = {
	"\x82\xcd\x82\xa2",
	"\x82\xa2\x82\xa2\x82\xa6"
};

static const StringListProvider kEoB1MenuYesNoStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1MenuYesNoStringsPC98Japanese), kEoB1MenuYesNoStringsPC98Japanese };

static const char *const kEoB1CharGuiStringsHpPC98Japanese[2] = {
	"HP",
	"%3d of %-3d"
};

static const StringListProvider kEoB1CharGuiStringsHpPC98JapaneseProvider = { ARRAYSIZE(kEoB1CharGuiStringsHpPC98Japanese), kEoB1CharGuiStringsHpPC98Japanese };

static const char *const kEoB1CharGuiStringsWp1PC98Japanese[2] = {
	"MISS",
	"HACK"
};

static const StringListProvider kEoB1CharGuiStringsWp1PC98JapaneseProvider = { ARRAYSIZE(kEoB1CharGuiStringsWp1PC98Japanese), kEoB1CharGuiStringsWp1PC98Japanese };

static const char *const kEoB1CharGuiStringsWrPC98Japanese[4] = {
	"CAN'T",
	"REACH",
	"NO",
	"AMMO"
};

static const StringListProvider kEoB1CharGuiStringsWrPC98JapaneseProvider = { ARRAYSIZE(kEoB1CharGuiStringsWrPC98Japanese), kEoB1CharGuiStringsWrPC98Japanese };

static const char *const kEoB1CharGuiStringsSt1PC98Japanese[6] = {
	"Swapping",
	"\x8e\x80\x82\xf1\x82\xc5\x82\xa2\x82\xe9",
	"\x8b""C""\x90\xe2\x82\xb5\x82\xc4\x82\xa2\x82\xe9",
	"\x93\xc5\x82\xf0\x8e\xf3\x82\xaf\x82\xc4\x82\xa2\x82\xe9\x81""i""\x92""x""\x82\xa2\x81""j",
	"\x93\xc5\x82\xf0\x8e\xf3\x82\xaf\x82\xc4\x82\xa2\x82\xe9",
	"\x96\x83\xe1\x83\x82\xb5\x82\xc4\x82\xa2\x82\xe9"
};

static const StringListProvider kEoB1CharGuiStringsSt1PC98JapaneseProvider = { ARRAYSIZE(kEoB1CharGuiStringsSt1PC98Japanese), kEoB1CharGuiStringsSt1PC98Japanese };

static const char *const kEoB1CharGuiStringsInPC98Japanese[4] = {
	"\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x8f\xee\x95\xf1",
	"\x83""A""\x81""[""\x83""}""\x81""[""\x83""N""\x83\x89\x83""X",
	"\x8c""o""\x8c\xb1\x92""l",
	"\x83\x8c\x83""x""\x83\x8b"
};

static const StringListProvider kEoB1CharGuiStringsInPC98JapaneseProvider = { ARRAYSIZE(kEoB1CharGuiStringsInPC98Japanese), kEoB1CharGuiStringsInPC98Japanese };

static const char *const kEoB1CharStatusStrings7PC98Japanese[1] = {
	"%s""\x82\xcd\x83""W""\x83\x83\x83""C""\x83""A""\x83\x93\x83""g""\x81""E""\x83""X""\x83""g""\x83\x8c\x83\x93\x83""O""\x83""X""\x82\xcc\x8c\xf8\x89\xca\x82\xf0\x8e\xb8\x82\xc1\x82\xbd\x81""B\r"
};

static const StringListProvider kEoB1CharStatusStrings7PC98JapaneseProvider = { ARRAYSIZE(kEoB1CharStatusStrings7PC98Japanese), kEoB1CharStatusStrings7PC98Japanese };

static const char *const kEoB1CharStatusStrings81PC98Japanese[1] = {
	"%s""\x82\xcd\x93\xc5\x82\xaa\x82\xdc\x82\xed\x82\xe9\x82\xcc\x82\xf0\x8a\xb4\x82\xb6\x82\xbd\x81""I\r"
};

static const StringListProvider kEoB1CharStatusStrings81PC98JapaneseProvider = { ARRAYSIZE(kEoB1CharStatusStrings81PC98Japanese), kEoB1CharStatusStrings81PC98Japanese };

static const char *const kEoB1CharStatusStrings9PC98Japanese[1] = {
	"%s""\x82\xcd\x96\x83\xe1\x83\x82\xa9\x82\xe7\x89\xf0\x95\xfa\x82\xb3\x82\xea\x82\xbd\x81""I\r"
};

static const StringListProvider kEoB1CharStatusStrings9PC98JapaneseProvider = { ARRAYSIZE(kEoB1CharStatusStrings9PC98Japanese), kEoB1CharStatusStrings9PC98Japanese };

static const char *const kEoB1CharStatusStrings131PC98Japanese[1] = {
	"%s""\x82\xcd""%s\r"
};

static const StringListProvider kEoB1CharStatusStrings131PC98JapaneseProvider = { ARRAYSIZE(kEoB1CharStatusStrings131PC98Japanese), kEoB1CharStatusStrings131PC98Japanese };

static const char *const kEoB1LevelGainStringsPC98Japanese[1] = {
	"\x06\x01""%s""\x82\xcd\x83\x8c\x83""x""\x83\x8b\x82\xaa\x82\xa0\x82\xaa\x82\xe9\x82\xcc\x82\xc9\x95""K""\x97""v""\x82\xc8\x8c""o""\x8c\xb1\x92""l""\x82\xf0\x93\xbe\x82\xbd\x81""B""\x06\x0f""\r"
};

static const StringListProvider kEoB1LevelGainStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1LevelGainStringsPC98Japanese), kEoB1LevelGainStringsPC98Japanese };

static const char *const kEoB1BookNumbersPC98Japanese[5] = {
	"First",
	"Second",
	"Third",
	"Fourth",
	"Fifth"
};

static const StringListProvider kEoB1BookNumbersPC98JapaneseProvider = { ARRAYSIZE(kEoB1BookNumbersPC98Japanese), kEoB1BookNumbersPC98Japanese };

static const char *const kEoB1MageSpellsListPC98Japanese[26] = {
	"",
	"\x83""A""\x81""[""\x83""}""\x81""[",
	"\x83""o""\x81""[""\x83""j""\x83\x93\x83""O""\x81""E""\x83""n""\x83\x93\x83""Y",
	"\x83""f""\x83""B""\x83""e""\x83""N""\x83""g""\x81""E""\x83""}""\x83""W""\x83""b""\x83""N",
	"\x83""}""\x83""W""\x83""b""\x83""N""\x81""E""\x83""~""\x83""T""\x83""C""\x83\x8b",
	"\x83\x8a\x81""[""\x83""h""\x81""E""\x83""}""\x83""W""\x83""b""\x83""N",
	"\x83""V""\x81""[""\x83\x8b\x83""h",
	"\x83""V""\x83\x87\x83""b""\x83""L""\x83\x93\x83""O""\x81""E""\x83""O""\x83\x89\x83""X""\x83""v",
	"\x83""C""\x83\x93\x83""r""\x83""W""\x83""r""\x83\x8a\x83""e""\x83""B",
	"\x83""m""\x83""b""\x83""N",
	"\x83\x81\x83\x8b\x83""t""\x83""Y""\x81""E""\x83""A""\x83""V""\x83""b""\x83""h""\x81""E""\x83""A""\x83\x8d\x81""[",
	"\x83""X""\x83""e""\x83""B""\x83\x93\x83""L""\x83\x93\x83""O""\x81""E""\x83""N""\x83\x89\x83""E""\x83""h",
	"\x83""f""\x83""B""\x83""X""\x83""y""\x83\x8b\x81""E""\x83""}""\x83""W""\x83""b""\x83""N",
	"\x83""t""\x83""@""\x83""C""\x83""A""\x83""{""\x81""[""\x83\x8b",
	"\x83""t""\x83\x8c\x83""C""\x83\x80\x81""E""\x83""A""\x83\x8d\x81""[",
	"\x83""w""\x83""C""\x83""X""\x83""g",
	"\x83""z""\x81""[""\x83\x8b\x83""h""\x81""E""\x83""p""\x81""[""\x83""X""\x83\x93",
	"\x83""C""\x83\x93\x83""r""\x83""W""\x83""r""\x83\x8a\x83""e""\x83""B""\x82""P""\x82""O",
	"\x83\x89\x83""C""\x83""g""\x83""j""\x83\x93\x83""O""\x81""E""\x83""{""\x83\x8b\x83""g",
	"\x83""o""\x83\x93\x83""s""\x83\x8a\x83""b""\x83""N""\x81""E""\x83""^""\x83""b""\x83""`",
	"\x83""t""\x83""B""\x83""A",
	"\x83""A""\x83""C""\x83""X""\x81""E""\x83""X""\x83""g""\x81""[""\x83\x80",
	"\x83""X""\x83""g""\x81""[""\x83\x93\x83""X""\x83""L""\x83\x93",
	"\x83""N""\x83\x89\x83""E""\x83""h""\x83""L""\x83\x8b",
	"\x83""R""\x81""[""\x83\x93\x81""E""\x83""I""\x83""u""\x81""E""\x83""R""\x81""[""\x83\x8b\x83""h",
	"\x83""z""\x81""[""\x83\x8b\x83""h""\x81""E""\x83\x82\x83\x93\x83""X""\x83""^""\x81""["
};

static const StringListProvider kEoB1MageSpellsListPC98JapaneseProvider = { ARRAYSIZE(kEoB1MageSpellsListPC98Japanese), kEoB1MageSpellsListPC98Japanese };

static const char *const kEoB1ClericSpellsListPC98Japanese[25] = {
	"",
	"\x83""u""\x83\x8c\x83""X",
	"\x83""L""\x83\x85\x83""A""\x81""E""\x83\x89\x83""C""\x83""g""\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""R""\x81""[""\x83""Y""\x81""E""\x83\x89\x83""C""\x83""g""\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""f""\x83""B""\x83""e""\x83""N""\x83""g""\x81""E""\x83""}""\x83""W""\x83""b""\x83""N",
	"\x83""v""\x83\x8d\x83""e""\x83""N""\x83""g""\x81""E""\x83""C""\x81""[""\x83""r""\x83\x8b",
	"\x83""G""\x83""C""\x83""h",
	"\x83""t""\x83\x8c\x83""C""\x83\x80\x81""E""\x83""u""\x83\x8c\x81""[""\x83""h",
	"\x83""z""\x81""[""\x83\x8b\x83""h""\x81""E""\x83""p""\x81""[""\x83""X""\x83\x93",
	"\x83""X""\x83\x8d\x81""[""\x81""E""\x83""|""\x83""C""\x83""Y""\x83\x93",
	"\x83""N""\x83\x8a\x83""G""\x83""C""\x83""g""\x81""E""\x83""t""\x81""[""\x83""h",
	"\x83""f""\x83""B""\x83""X""\x83""y""\x83\x8b\x81""E""\x83""}""\x83""W""\x83""b""\x83""N",
	"\x83""}""\x83""W""\x83""J""\x83\x8b\x81""E""\x83""x""\x83""X""\x83""g""\x83\x81\x83\x93\x83""g",
	"\x83""v""\x83\x8c\x83""C""\x83\x84\x81""[",
	"\x83\x8a\x83\x80\x81""[""\x83""u""\x81""E""\x83""p""\x83\x89\x83\x8a\x83""V""\x83""X",
	"\x83""L""\x83\x85\x83""A""\x81""E""\x83""V""\x83\x8a\x83""A""\x83""X""\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""R""\x81""[""\x83""Y""\x81""E""\x83""V""\x83\x8a\x83""A""\x83""X""\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""j""\x83\x85\x81""[""\x83""g""\x83\x89\x83\x89\x83""C""\x83""Y""\x81""E""\x83""|""\x83""C""\x83""Y""\x83\x93",
	"\x83""v""\x83\x8d\x83""e""\x83""N""\x83""V""\x83\x87\x83\x93\x81""E""\x83""C""\x81""[""\x83""r""\x83\x8b\x82""P""\x82""O",
	"\x83""v""\x83\x8d\x83""e""\x83""N""\x83""V""\x83\x87\x83\x93\x81""E""\x83\x89\x83""C""\x83""g""\x83""j""\x83\x93\x83""O",
	"\x83""L""\x83\x85\x83""A""\x81""E""\x83""N""\x83\x8a\x83""e""\x83""B""\x83""J""\x83\x8b\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""R""\x81""[""\x83""Y""\x81""E""\x83""N""\x83\x8a\x83""e""\x83""B""\x83""J""\x83\x8b\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""t""\x83\x8c\x83""C""\x83\x80\x81""E""\x83""X""\x83""g""\x83\x89\x83""C""\x83""N",
	"\x83\x8c\x83""C""\x83""Y""\x81""E""\x83""f""\x83""b""\x83""h",
	"\x83\x8c\x83""C""\x81""E""\x83""I""\x83\x93\x81""E""\x83""n""\x83\x93\x83""Y"
};

static const StringListProvider kEoB1ClericSpellsListPC98JapaneseProvider = { ARRAYSIZE(kEoB1ClericSpellsListPC98Japanese), kEoB1ClericSpellsListPC98Japanese };

static const char *const kEoB1SpellNamesPC98Japanese[51] = {
	"",
	"\x83""A""\x81""[""\x83""}""\x81""[",
	"\x83""o""\x81""[""\x83""j""\x83\x93\x83""O""\x81""E""\x83""n""\x83\x93\x83""Y",
	"\x83""f""\x83""B""\x83""e""\x83""N""\x83""g""\x81""E""\x83""}""\x83""W""\x83""b""\x83""N",
	"\x83""}""\x83""W""\x83""b""\x83""N""\x81""E""\x83""~""\x83""T""\x83""C""\x83\x8b",
	"\x83""V""\x81""[""\x83\x8b\x83""h",
	"\x83""V""\x83\x87\x83""b""\x83""L""\x83\x93\x83""O""\x81""E""\x83""O""\x83\x89\x83""X""\x83""v",
	"\x83""C""\x83\x93\x83""r""\x83""W""\x83""r""\x83\x8a\x83""e""\x83""B",
	"\x83\x81\x83\x8b\x83""t""\x83""Y""\x81""E""\x83""A""\x83""V""\x83""b""\x83""h""\x81""E""\x83""A""\x83\x8d\x81""[",
	"\x83""X""\x83""e""\x83""B""\x83\x93\x83""L""\x83\x93\x83""O""\x81""E""\x83""N""\x83\x89\x83""E""\x83""h",
	"\x83""f""\x83""B""\x83""X""\x83""y""\x83\x8b\x81""E""\x83""}""\x83""W""\x83""b""\x83""N",
	"\x83""t""\x83""@""\x83""C""\x83""A""\x83""{""\x81""[""\x83\x8b",
	"\x83""t""\x83\x8c\x83""C""\x83\x80\x81""E""\x83""A""\x83\x8d\x81""[",
	"\x83""w""\x83""C""\x83""X""\x83""g",
	"\x83""z""\x81""[""\x83\x8b\x83""h""\x81""E""\x83""p""\x81""[""\x83""X""\x83\x93",
	"\x83""C""\x83\x93\x83""r""\x83""W""\x83""r""\x83\x8a\x83""e""\x83""B""\x82""P""\x82""O""\x83""t""\x83""B""\x81""[""\x83""g""\x81""E""\x83\x8c\x83""C""\x83""f""\x83""B""\x83""A""\x83""X",
	"\x83\x89\x83""C""\x83""g""\x83""j""\x83\x93\x83""O""\x81""E""\x83""{""\x83\x8b\x83""g",
	"\x83""o""\x83\x93\x83""s""\x83\x8a\x83""b""\x83""N""\x81""E""\x83""^""\x83""b""\x83""`",
	"\x83""t""\x83""B""\x83""A",
	"\x83""A""\x83""C""\x83""X""\x81""E""\x83""X""\x83""g""\x81""[""\x83\x80",
	"\x83""X""\x83""g""\x81""[""\x83\x93\x83""X""\x83""L""\x83\x93",
	"\x83""N""\x83\x89\x83""E""\x83""h""\x83""L""\x83\x8b",
	"\x83""R""\x81""[""\x83\x93\x81""E""\x83""I""\x83""u""\x81""E""\x83""R""\x81""[""\x83\x8b\x83""h",
	"\x83""z""\x81""[""\x83\x8b\x83""h""\x81""E""\x83\x82\x83\x93\x83""X""\x83""^""\x81""[",
	"\x83""u""\x83\x8c\x83""X",
	"\x83""L""\x83\x85\x83""A""\x81""E""\x83\x89\x83""C""\x83""g""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""R""\x81""[""\x83""Y""\x81""E""\x83\x89\x83""C""\x83""g""\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""f""\x83""B""\x83""e""\x83""N""\x83""g""\x81""E""\x83""}""\x83""W""\x83""b""\x83""N",
	"\x83""v""\x83\x8d\x83""e""\x83""N""\x83""V""\x83\x87\x83\x93\x81""E""\x83""C""\x81""[""\x83""r""\x83\x8b",
	"\x83""G""\x83""C""\x83""h",
	"\x83""t""\x83\x8c\x83""C""\x83\x80\x81""E""\x83""u""\x83\x8c\x81""[""\x83""h",
	"\x83""z""\x81""[""\x83\x8b\x83""h""\x81""E""\x83""p""\x81""[""\x83""X""\x83\x93",
	"\x83""X""\x83\x8d\x81""[""\x81""E""\x83""|""\x83""C""\x83""Y""\x83\x93",
	"\x83""N""\x83\x8a\x83""G""\x83""C""\x83""g""\x81""E""\x83""t""\x81""[""\x83""h",
	"\x83""f""\x83""B""\x83""X""\x83""y""\x83\x8b\x81""E""\x83""}""\x83""W""\x83""b""\x83""N",
	"\x83""}""\x83""W""\x83""J""\x83\x8b\x81""E""\x83""x""\x83""X""\x83""g""\x83\x81\x83\x93\x83""g",
	"\x83""v""\x83\x8c\x83""C""\x83\x84\x81""[",
	"\x83\x8a\x83\x80\x81""[""\x83""u""\x81""E""\x83""p""\x83\x89\x83\x8a\x83""V""\x83""X",
	"\x83""L""\x83\x85\x83""A""\x81""E""\x83""V""\x83\x8a\x83""A""\x83""X""\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""R""\x81""[""\x83""Y""\x81""E""\x83""V""\x83\x8a\x83""A""\x83""X""\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""j""\x83\x85\x81""[""\x83""g""\x83\x89\x83\x89\x83""C""\x83""Y""\x81""E""\x83""|""\x83""C""\x83""Y""\x83\x93",
	"\x83""v""\x83\x8d\x83""e""\x83""N""\x83""V""\x83\x87\x83\x93\x81""E""\x83""C""\x81""[""\x83""r""\x83\x8b\x82""P""\x82""O",
	"\x83""v""\x83\x8d\x83""e""\x83""N""\x83""V""\x83\x87\x83\x93\x81""E""\x83\x89\x83""C""\x83""g""\x83""j""\x83\x93\x83""O",
	"\x83""L""\x83\x85\x83""A""\x81""E""\x83""N""\x83\x8a\x83""e""\x83""B""\x83""J""\x83\x8b\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""R""\x81""[""\x83""Y""\x81""E""\x83""N""\x83\x8a\x83""e""\x83""B""\x83""J""\x83\x8b\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y",
	"\x83""t""\x83\x8c\x83""C""\x83\x80\x81""E""\x83""X""\x83""g""\x83\x89\x83""C""\x83""N",
	"\x83\x8c\x83""C""\x83""Y""\x81""E""\x83""f""\x83""b""\x83""h",
	"\x83\x8c\x83""C""\x81""E""\x83""I""\x83\x93\x81""E""\x83""n""\x83\x93\x83""Y",
	"",
	"",
	""
};

static const StringListProvider kEoB1SpellNamesPC98JapaneseProvider = { ARRAYSIZE(kEoB1SpellNamesPC98Japanese), kEoB1SpellNamesPC98Japanese };

static const char *const kEoB1MagicStrings1PC98Japanese[6] = {
	"ABORT SPELL",
	"ABORT SPELL",
	"\x82\xb1\x82\xcc\x8e\xf4\x95\xb6\x82\xf0\x82\xa9\x82\xaf\x82\xe9\x82\xc9\x82\xcd\x95\xd0\x8e\xe8\x82\xaa\x8e\xa9\x97""R""\x82\xc5\x82\xc8\x82\xaf\x82\xea\x82\xce\x82\xa2\x82\xaf\x82\xc8\x82\xa2\x81""B\r",
	"\x82\xb1\x82\xcc\x83""^""\x83""C""\x83""v""\x82\xcc\x8e\xf4\x95\xb6\x82\xcd\x93\xaf\x8e\x9e\x82\xc9\x82""Q""\x82\xc2\x8c\xf8\x89\xca\x82\xf0\x8e\x9d\x82\xc2\x82\xb1\x82\xc6\x82\xcd\x82\xc5\x82\xab\x82\xc8\x82\xa2\x81""B\r",
	"%s""\x82\xcd""%s""\x82\xcc\x8e\xf4\x95\xb6\x82\xf0\x8f\xa5\x82\xa6\x82\xbd""\r",
	"\x82\x8f\x82\x8b""\r"
};

static const StringListProvider kEoB1MagicStrings1PC98JapaneseProvider = { ARRAYSIZE(kEoB1MagicStrings1PC98Japanese), kEoB1MagicStrings1PC98Japanese };

static const char *const kEoB1MagicStrings2PC98Japanese[3] = {
	"\x89""e""\x8b\xbf\x82\xcd\x82\xc8\x82\xa9\x82\xc1\x82\xbd\x81""B\r",
	"%s""\x82\xcd\x82\xce\x82\xe7\x82\xce\x82\xe7\x82\xc9\x95\xaa\x89\xf0\x82\xb5\x82\xc4\x82\xb5\x82\xdc\x82\xc1\x82\xbd\x81""I\r",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcd\x8e\x80\x82\xcc\x8e\xf4\x95\xb6\x82\xc5\x8d""U""\x8c\x82\x82\xb3\x82\xea\x82\xbd\x81""I\r",
};

static const StringListProvider kEoB1MagicStrings2PC98JapaneseProvider = { ARRAYSIZE(kEoB1MagicStrings2PC98Japanese), kEoB1MagicStrings2PC98Japanese };

static const char *const kEoB1MagicStrings3PC98Japanese[6] = {
	"\x82\xc7\x82\xcc\x83""L""\x83\x83\x83\x89\x83""N""\x83""^""\x81""[""\x82\xc9\x8e\xf4\x95\xb6\x82\xf0\x82\xa9\x82\xaf\x82\xdc\x82\xb7\x82\xa9\x81""H""\x81""@",
	"\r""\x82\x8f\x82\x8b""\r",
	"\r""\x8e\xf4\x95\xb6\x82\xcd\x8e\xb8\x82\xed\x82\xea\x82\xbd\x81""B\r",
	"%s""\x82\xc9\x82\xa9\x82\xa9\x82\xc1\x82\xc4\x82\xa2\x82\xbd""%s""\x82\xcc\x8c\xf8\x89\xca\x82\xaa\x82\xc8\x82\xad\x82\xc8\x82\xc1\x82\xbd\x81""B\r",
	"%s""\x82\xcc\x8e\xf4\x95\xb6\x82\xcd\x83\x82\x83\x93\x83""X""\x83""^""\x81""[""\x82\xc9\x8c\xf8\x89\xca\x82\xaa\x82\xc8\x82\xa9\x82\xc1\x82\xbd\x81""B\r",
	"%s""\x82\xaa\x8d""U""\x8c\x82\x82\xb7\x82\xe9\x82\xc9\x82\xcd\x91""O""\x97\xf1\x82\xc9\x82\xa2\x82\xc8\x82\xaf\x82\xea\x82\xce\x82\xc8\x82\xe7\x82\xc8\x82\xa2\x81""B\r"
};

static const StringListProvider kEoB1MagicStrings3PC98JapaneseProvider = { ARRAYSIZE(kEoB1MagicStrings3PC98Japanese), kEoB1MagicStrings3PC98Japanese };

static const char *const kEoB1MagicStrings4PC98Japanese[1] = {
	"\x89""e""\x8b\xbf\x82\xcd\x82\xc8\x82\xa9\x82\xc1\x82\xbd\x81""B\r"
};

static const StringListProvider kEoB1MagicStrings4PC98JapaneseProvider = { ARRAYSIZE(kEoB1MagicStrings4PC98Japanese), kEoB1MagicStrings4PC98Japanese };

static const char *const kEoB1MagicStrings6PC98Japanese[1] = {
	"%s""\x82\xcc\x83""A""\x81""[""\x83""}""\x81""[""\x81""E""\x83""N""\x83\x89\x83""X""\x82\xcd\x82\xb7\x82\xc5\x82\xc9\x8f""[""\x95\xaa\x8d\x82\x82\xa2\x81""B\r"
};

static const StringListProvider kEoB1MagicStrings6PC98JapaneseProvider = { ARRAYSIZE(kEoB1MagicStrings6PC98Japanese), kEoB1MagicStrings6PC98Japanese };

static const char *const kEoB1MagicStrings7PC98Japanese[5] = {
	"1ST",
	"2ND",
	"3RD",
	"4TH",
	"5TH"
};

static const StringListProvider kEoB1MagicStrings7PC98JapaneseProvider = { ARRAYSIZE(kEoB1MagicStrings7PC98Japanese), kEoB1MagicStrings7PC98Japanese };

static const char *const kEoB1MagicStrings8PC98Japanese[3] = {
	"%s""\x82\xc9\x82\xa9\x82\xa9\x82\xc1\x82\xc4\x82\xa2\x82\xbd\x8e\xf4\x95\xb6\x82\xcd\x82\xb7\x82\xd7\x82\xc4\x8f\xc1\x82\xb5\x8b\x8e\x82\xe7\x82\xea\x82\xbd\x81""B\r",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcd\x82\xb7\x82\xc5\x82\xc9\x8f""j""\x95\x9f\x82\xf0\x8e\xf3\x82\xaf\x82\xc4\x82\xa2\x82\xe9\x81""I\r",
	"\x89\x87\x8f\x95\x82\xcc\x8e\xf4\x95\xb6\x82\xcd\x8e\xb8\x94""s""\x82\xb5\x82\xbd\x81""I\r"
};

static const StringListProvider kEoB1MagicStrings8PC98JapaneseProvider = { ARRAYSIZE(kEoB1MagicStrings8PC98Japanese), kEoB1MagicStrings8PC98Japanese };

static const char *const kEoB1MonsterDistAttStringsPC98Japanese[5] = {
	"%s""\x82\xcd\x83""R""\x81""[""\x83""Y""\x81""E""\x83""V""\x83\x8a\x83""A""\x83""X""\x81""E""\x83""E""\x81""[""\x83\x93\x83""Y""\x82\xcc\x8e\xf4\x95\xb6\x82\xc5\x8d""U""\x8c\x82\x82\xb3\x82\xea\x82\xbd\x81""I\r",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x82\xcd\x90\xb8\x90""_""\x94""g""\x8d""U""\x8c\x82\x82\xf0\x8e\xf3\x82\xaf\x82\xbd\x81""I\r",
	"\x96\x83\xe1\x83\x82\xb5\x82\xc4\x82\xa2\x82\xe9",
	"\x93\xc5\x82\xf0\x8e\xf3\x82\xaf\x82\xbd",
	"\x96\x83\xe1\x83\x82\xb5\x82\xbd"
};

static const StringListProvider kEoB1MonsterDistAttStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1MonsterDistAttStringsPC98Japanese), kEoB1MonsterDistAttStringsPC98Japanese };

static const char *const kEoB1IntroStringsTowerPC98Japanese[3] = {
	"\x83""E""\x83""H""\x81""[""\x83""^""\x81""[""\x83""f""\x83""B""\x81""[""\x83""v""\x82\xc9\x8e\xd7\x88\xab\x82\xcc\x89""e""\x82\xaa\x94""E""\x82\xd1\x8a\xf1\x82\xc1\x82\xc4\x82\xa2\x82\xe9\x81""B",
	"\x82\xed\x82\xea\x82\xed\x82\xea\x97\xcc\x8e\xe5\x82\xcd\x81""A""\x82\xbb\x82\xea\x82\xf0\x8e\xe6\x82\xe8\x8f\x9c\x82\xad\x95\xfb\x8d\xf4\x82\xf0\x8c\xa9\x82\xc2\x82\xaf\x82\xcb\x82\xce\x82\xc8\x82\xe7\x82\xca\x81""B",
	"\x8d\x91\x92\x86\x82\xcc\x89""p""\x97""Y""\x82\xbd\x82\xbf\x82\xc9\x8c\xc4\x82\xd1\x82\xa9\x82\xaf\x81""A""\x97""E""\x8e""m""\x82\xf0\x91""I""\x82\xda\x82\xa4\x81""B"
};

static const StringListProvider kEoB1IntroStringsTowerPC98JapaneseProvider = { ARRAYSIZE(kEoB1IntroStringsTowerPC98Japanese), kEoB1IntroStringsTowerPC98Japanese };

static const char *const kEoB1IntroStringsOrbPC98Japanese[1] = {
	"\x82\xb2\x8e\xe5\x90""l""\x82\xb3\x82\xdc\x81""c""\x81""c""\x81""B"
};

static const StringListProvider kEoB1IntroStringsOrbPC98JapaneseProvider = { ARRAYSIZE(kEoB1IntroStringsOrbPC98Japanese), kEoB1IntroStringsOrbPC98Japanese };

static const char *const kEoB1IntroStringsWdEntryPC98Japanese[1] = {
	"\x82\xe2\x82\xc2\x82\xe7\x82\xcd\x82\xc2\x82\xdc\x82\xe7\x82\xca\x92\xef\x8d""R""\x82\xf0\x8d""l""\x82\xa6\x82\xbd\x82\xe6\x82\xa4\x82\xc5\x82\xb7\x81""B"
};

static const StringListProvider kEoB1IntroStringsWdEntryPC98JapaneseProvider = { ARRAYSIZE(kEoB1IntroStringsWdEntryPC98Japanese), kEoB1IntroStringsWdEntryPC98Japanese };

static const char *const kEoB1IntroStringsKingPC98Japanese[1] = {
	"\x8c""N""\x82\xbd\x82\xbf\x82\xc9\x94""C""\x96\xb1\x82\xf0\x82\xbd\x82\xad\x82\xb7\x81""B""\x82\xb1\x82\xcc\x88\xab\x82\xcc\x96""{""\x8e\xbf\x82\xf0\x92""T""\x82\xe8\x81""A""\x82\xb3\x82\xe7\x82\xc9\x82\xcd\x94""j""\x89\xf3\x82\xb9\x82\xe6\x81""B"
};

static const StringListProvider kEoB1IntroStringsKingPC98JapaneseProvider = { ARRAYSIZE(kEoB1IntroStringsKingPC98Japanese), kEoB1IntroStringsKingPC98Japanese };

static const char *const kEoB1IntroStringsHandsPC98Japanese[1] = {
	"\x8a\xeb\x8c\xaf\x82\xc8\x97\xb7\x82\xc5\x82\xa0\x82\xeb\x82\xa4\x81""B""\x8f\x80\x94\xf5\x82\xf0\x91\xd3\x82\xe9\x82\xc8\x81""B"
};

static const StringListProvider kEoB1IntroStringsHandsPC98JapaneseProvider = { ARRAYSIZE(kEoB1IntroStringsHandsPC98Japanese), kEoB1IntroStringsHandsPC98Japanese };

static const char *const kEoB1IntroStringsWdExitPC98Japanese[1] = {
	"\x92""T""\x8d\xf5\x82\xcd\x92\xac\x82\xcc\x92""n""\x89\xba\x82\xa9\x82\xe7\x82\xcd\x82\xb6\x82\xdf\x82\xc4\x82\xad\x82\xea\x81""B"
};

static const StringListProvider kEoB1IntroStringsWdExitPC98JapaneseProvider = { ARRAYSIZE(kEoB1IntroStringsWdExitPC98Japanese), kEoB1IntroStringsWdExitPC98Japanese };

static const char *const kEoB1IntroStringsTunnelPC98Japanese[2] = {
	"",
	"\x82\xe2\x82\xc2\x82\xe7\x82\xcc\x89""^""\x96\xbd\x82\xcd\x95\x95\x82\xb6\x82\xe7\x82\xea\x82\xbd\x81""B"
};

static const StringListProvider kEoB1IntroStringsTunnelPC98JapaneseProvider = { ARRAYSIZE(kEoB1IntroStringsTunnelPC98Japanese), kEoB1IntroStringsTunnelPC98Japanese };

static const char *const kEoB1FinaleStringsPC98Japanese[17] = {
	"\x83""p""\x81""[""\x83""e""\x83""B""\x82\xcd\x82\xae\x82\xbf\x82\xe1\x82\xae\x82\xbf\x82\xe1\x82\xc9\x82\xc8\x82\xc1\x82\xbd\x83""N""\x83""T""\x83""i""\x83""^""\x81""[""\x83\x8b\x82\xcc\x8e\x80\x91\xcc\x82\xcc\x8e""c""\x8a""[""\x82\xf0\x92""T""\x82\xc1\x82\xbd\x81""B",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcd\x83""N""\x83""T""\x83""i""\x83""^""\x81""[""\x83\x8b\x82\xf0\x93""|""\x82\xb5\x82\xbd\x81""B",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x81""[""\x82\xcd\x8e\xe5\x82\xcc\x82\xa2\x82\xc8\x82\xa2\x83""N""\x83""T""\x83""i""\x83""^""\x81""[""\x83\x8b\x82\xcc\x91\x83\x82\xf0\x82\xb3\x82\xdc\x82\xe6\x82\xa2\x81""A",
	"\x8f""o""\x8c\xfb\x82\xd6\x82\xcc\x8e\xe8\x82\xaa\x82\xa9\x82\xe8\x82\xf0\x92""T""\x82\xb5\x82\xbd\x81""B",
	"\x82\xbb\x82\xcc\x82\xa4\x82\xbf\x82\xc9\x92\x86\x82\xcc\x83""e""\x83\x8c\x83""|""\x81""[""\x83""^""\x82\xcc\x83""X""\x83""C""\x83""b""\x83""`""\x82\xaa\x93\xfc\x82\xc1\x82\xc4\x82\xb5\x82\xdc\x82\xc1\x82\xbd\x81""B",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x82\xcc\x82\xdc\x82\xed\x82\xe8\x82\xc5\x91\x91\x8c\xb5\x82\xc8\x91\xe5\x97\x9d\x90\xce\x82\xcc\x95\x94\x89\xae\x82\xaa\x82\xb5\x82\xbe\x82\xa2\x82\xc9\x96\xbe\x82\xe9\x82\xb3\x82\xf0\x91\x9d\x82\xb5\x82\xbd\x81""B""\x07",
	"\x82""Q""\x96""{""\x82\xcc\x90\xce\x92\x8c\x82\xaa\x91\xe5\x82\xab\x82\xc8\x8b\xca\x8d\xc0\x82\xcc\x97\xbc\x98""e""\x82\xc9\x82\xbb\x82\xd1\x82\xa6\x82\xc4\x82\xa2\x82\xe9\x81""B""\x07",
	"\x82\xb1\x82\xb1\x82\xcd\x83""s""\x83""A""\x83""W""\x83""F""\x83""C""\x83\x8d\x83\x93\x82\xcc\x89""y""\x8c\xa9\x82\xcc\x8a\xd4\x82\xbe\x81""B""\x07",
	"\x83""p""\x81""[""\x83""e""\x83""B""\x82\xcd\x83""E""\x83""H""\x81""[""\x83""^""\x81""[""\x83""f""\x83""B""\x81""[""\x83""v""\x92""n""\x89\xba\x82\xcc\x96\xc0\x8b""{""\x82\xa9\x82\xe7\x82\xe2\x82\xc1\x82\xc6\x89\xf0\x95\xfa\x82\xb3\x82\xea\x82\xbd\x82\xcc\x82\xbe\x81""B",
	"\x82\xa8\x82\xdf\x82\xc5\x82\xc6\x82\xa4\x81""I""\x81""I",
	"\x82\xa0\x82\xc8\x82\xbd\x82\xcd\x82""P""\x82""Q""\x82\xcc\x93\xc1\x95\xca\x92""T""\x8d\xf5\x82\xf0\x82\xb7\x82\xd7\x82\xc4\x92""B""\x90\xac\x82\xb5\x82\xdc\x82\xb5\x82\xbd\x81""B",
	"\x83""{""\x81""[""\x83""i""\x83""X""\x82\xf0\x8f\x9f\x82\xbf\x8e\xe6\x82\xc1\x82\xbd",
	"\x81""u""\x8c""N""\x92""B""\x82\xcd\x83""N""\x83""T""\x83""i""\x83""^""\x81""[""\x83\x8b\x82\xf0\x93""|""\x82\xb5\x81""A""\x83""E""\x83""H""\x81""[""\x83""^""\x81""[""\x83""f""\x83""B""\x81""[""\x83""v""\x82\xf0\x93""z""\x82\xcc\x88\xab\x82\xa9\x82\xe7\x8b""~""\x82\xc1\x82\xc4\x82\xad\x82\xea\x82\xbd\x81""I""\x81""v""\x82\xc6\x07",
	"\x83""s""\x83""A""\x83""W""\x83""F""\x83""C""\x83\x8d\x83\x93\x81""E""\x83""p""\x83\x89\x83""f""\x83""B""\x83\x93\x83""\\""\x83\x93\x82\xaa\x90\xba\x8d\x82\x82\xc9\x8c\xbe\x82\xa4\x81""B""\x07",
	"\x82\xb1\x82\xcc\x82\xe6\x82\xa4\x82\xc9\x97""L""\x94""\\""\x82\xc5\x8d\xcb\x8a""o""\x82\xcc\x82\xa0\x82\xe9\x96""`""\x8c\xaf\x8e\xd2\x82\xf0\x91""I""\x82\xf1\x82\xc5\x90\xb3\x89\xf0\x82\xbe\x82\xc1\x82\xbd\x81""B""\x07",
	"\x8d\xa1\x93\xfa\x82\xe6\x82\xe8\x82\xbb\x82\xc8\x82\xbd\x92""B""\x82\xcd\x81""u""\x83""E""\x83""H""\x81""[""\x83""^""\x81""[""\x83""f""\x83""B""\x81""[""\x83""v""\x82\xcc\x89""p""\x97""Y""\x81""v""\x82\xcc\x96\xbc\x82\xc5\x8c\xc4\x82\xce\x82\xea\x81""A""\x07",
	"\x82\xb7\x82\xd7\x82\xc4\x82\xcc\x82\xe0\x82\xcc\x82\xaa\x82\xbb\x82\xcc\x97""E""\x8a\xb8\x82\xc8\x82\xd3\x82\xe9\x82\xdc\x82\xa2\x82\xf0\x92""m""\x82\xe9\x82\xb1\x82\xc6\x82\xbe\x82\xeb\x82\xa4\x81""I ""\x92""T""\x8d\xf5\x92""B""\x90\xac\x81""A""\x82\xa8\x82\xdf\x82\xc5\x82\xc6\x82\xa4\x81""I"
};

static const StringListProvider kEoB1FinaleStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1FinaleStringsPC98Japanese), kEoB1FinaleStringsPC98Japanese };

static const byte kEoB1CreditsStringsPC98Japanese[459] = {
	0x0d, 0x08, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x53, 0x74, 0x61, 0x66, 0x66, 0x0d, 0x0c, 0x50,
	0x72, 0x6f, 0x6a, 0x65, 0x63, 0x74, 0x20, 0x4c, 0x65, 0x61, 0x64, 0x65, 0x72, 0x0d, 0x08, 0x20,
	0x20, 0x20, 0x20, 0x59, 0x61, 0x73, 0x75, 0x74, 0x61, 0x6b, 0x61, 0x20, 0x55, 0x6b, 0x61, 0x69,
	0x0d, 0x0c, 0x43, 0x68, 0x69, 0x65, 0x66, 0x20, 0x50, 0x72, 0x6f, 0x67, 0x72, 0x61, 0x6d, 0x6d,
	0x65, 0x72, 0x0d, 0x08, 0x20, 0x20, 0x20, 0x20, 0x4d, 0x61, 0x6b, 0x6f, 0x74, 0x6f, 0x20, 0x49,
	0x63, 0x68, 0x69, 0x6e, 0x6f, 0x73, 0x65, 0x6b, 0x69, 0x0d, 0x0c, 0x53, 0x75, 0x62, 0x20, 0x50,
	0x72, 0x6f, 0x67, 0x72, 0x61, 0x6d, 0x6d, 0x65, 0x72, 0x0d, 0x08, 0x20, 0x20, 0x20, 0x20, 0x48,
	0x69, 0x72, 0x6f, 0x79, 0x75, 0x6b, 0x69, 0x20, 0x46, 0x75, 0x6a, 0x69, 0x77, 0x61, 0x72, 0x61,
	0x0d, 0x20, 0x20, 0x20, 0x20, 0x48, 0x69, 0x64, 0x65, 0x66, 0x75, 0x6d, 0x69, 0x20, 0x4f, 0x68,
	0x61, 0x72, 0x61, 0x0d, 0x0c, 0x47, 0x72, 0x61, 0x70, 0x68, 0x69, 0x63, 0x20, 0x44, 0x65, 0x73,
	0x69, 0x67, 0x6e, 0x0d, 0x08, 0x20, 0x20, 0x20, 0x20, 0x41, 0x74, 0x73, 0x75, 0x68, 0x69, 0x72,
	0x6f, 0x20, 0x47, 0x75, 0x6e, 0x6a, 0x69, 0x0d, 0x20, 0x20, 0x20, 0x20, 0x52, 0x69, 0x65, 0x6b,
	0x6f, 0x20, 0x59, 0x6f, 0x73, 0x68, 0x69, 0x64, 0x61, 0x0d, 0x0c, 0x4d, 0x75, 0x73, 0x69, 0x63,
	0x0d, 0x08, 0x20, 0x20, 0x20, 0x20, 0x59, 0x75, 0x7a, 0x6f, 0x20, 0x4b, 0x6f, 0x73, 0x68, 0x69,
	0x72, 0x6f, 0x0d, 0x20, 0x20, 0x20, 0x20, 0x59, 0x75, 0x6a, 0x69, 0x20, 0x59, 0x61, 0x6d, 0x61,
	0x64, 0x61, 0x0d, 0x0c, 0x54, 0x72, 0x61, 0x6e, 0x73, 0x6c, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x20,
	0x26, 0x20, 0x53, 0x75, 0x70, 0x65, 0x72, 0x76, 0x69, 0x73, 0x69, 0x6f, 0x6e, 0x0d, 0x08, 0x20,
	0x20, 0x20, 0x20, 0x48, 0x69, 0x74, 0x6f, 0x73, 0x68, 0x69, 0x20, 0x59, 0x61, 0x73, 0x75, 0x64,
	0x61, 0x0d, 0x20, 0x20, 0x20, 0x20, 0x4d, 0x69, 0x79, 0x75, 0x6b, 0x69, 0x20, 0x4b, 0x69, 0x79,
	0x6f, 0x6d, 0x61, 0x74, 0x73, 0x75, 0x0d, 0x20, 0x20, 0x20, 0x20, 0x4d, 0x65, 0x67, 0x75, 0x6d,
	0x69, 0x20, 0x54, 0x73, 0x75, 0x67, 0x65, 0x0d, 0x0c, 0x50, 0x72, 0x6f, 0x6d, 0x6f, 0x74, 0x69,
	0x6f, 0x6e, 0x0d, 0x08, 0x20, 0x20, 0x20, 0x20, 0x59, 0x6f, 0x73, 0x68, 0x69, 0x61, 0x6b, 0x69,
	0x20, 0x4d, 0x61, 0x74, 0x73, 0x75, 0x6d, 0x6f, 0x74, 0x6f, 0x0d, 0x20, 0x20, 0x20, 0x20, 0x4e,
	0x6f, 0x62, 0x75, 0x61, 0x6b, 0x69, 0x20, 0x53, 0x75, 0x7a, 0x75, 0x6b, 0x69, 0x0d, 0x0c, 0x44,
	0x65, 0x62, 0x75, 0x67, 0x0d, 0x08, 0x20, 0x20, 0x20, 0x20, 0x4d, 0x61, 0x73, 0x61, 0x61, 0x6b,
	0x69, 0x20, 0x46, 0x75, 0x72, 0x75, 0x79, 0x61, 0x0d, 0x20, 0x20, 0x20, 0x20, 0x4b, 0x69, 0x79,
	0x6f, 0x74, 0x6f, 0x20, 0x59, 0x6f, 0x73, 0x68, 0x69, 0x6d, 0x75, 0x72, 0x61, 0x0d, 0x0c, 0x40,
	0x0d, 0x08, 0x20, 0x54, 0x68, 0x75, 0x73, 0x20, 0x62, 0x65, 0x67, 0x69, 0x6e, 0x73, 0x20, 0x61,
	0x20, 0x6c, 0x65, 0x67, 0x65, 0x6e, 0x64, 0x5b, 0x0d, 0x0c, 0x00
};

static const ByteProvider kEoB1CreditsStringsPC98JapaneseProvider = { ARRAYSIZE(kEoB1CreditsStringsPC98Japanese), kEoB1CreditsStringsPC98Japanese };

static const char *const kEoB1NpcPresetsNamesPC98Japanese[9] = {
	"\xb1\xc6\xac",
	"\xcb\xde\xb5\xd7\xd1",
	"\xb7\xd7\xbd",
	"\xb2\xda\xd8\xb1",
	"\xc3\xa8\xd7",
	"\xc4\xaf\xc4\xde\xb1\xaf\xcc\xdf\xcb\xd9",
	"\xc0\xba\xde\xb0\xd9",
	"\xc4\xde\xb0\xd7\xd1",
	"\xb7\xb1\xb6\xde\xb0"
};

static const StringListProvider kEoB1NpcPresetsNamesPC98JapaneseProvider = { ARRAYSIZE(kEoB1NpcPresetsNamesPC98Japanese), kEoB1NpcPresetsNamesPC98Japanese };
